package Text::Highlight::PHP;
use strict;

sub syntax
{
	return {
          'name' => 'PHP',
          'blockCommentOn' => [
                                '/*'
                              ],
          'case' => 0,
          'key2' => {
                      'long2ip' => 1,
                      'hw_getusername' => 1,
                      'odbc_commit' => 1,
                      'imagecolorset' => 1,
                      'mysql_fetch_object' => 1,
                      'satellite_exception_id' => 1,
                      'dbmdelete' => 1,
                      'sybase_min_client_severity' => 1,
                      'cpdf_set_leading' => 1,
                      'preg_split' => 1,
                      'imap_deletemailbox' => 1,
                      'fdf_set_ap' => 1,
                      'mysql_errno' => 1,
                      'imagedashedline' => 1,
                      'mssql_close' => 1,
                      'register_shutdown_function' => 1,
                      'pdf_begin_page' => 1,
                      'dba_open' => 1,
                      'posix_setsid' => 1,
                      'ibase_commit' => 1,
                      'imap_getsubscribed' => 1,
                      'odbc_close' => 1,
                      'is_executable' => 1,
                      'filemtime' => 1,
                      'apache_lookup_uri' => 1,
                      'yaz_syntax' => 1,
                      'gmp_setbit' => 1,
                      'gmp_sub' => 1,
                      'bcpow' => 1,
                      'getrusage' => 1,
                      'swf_addcolor' => 1,
                      'imap_check' => 1,
                      'implode' => 1,
                      'hw_edittext' => 1,
                      'str_pad' => 1,
                      'session_set_save_handler' => 1,
                      'php_uname' => 1,
                      'pg_fetch_object' => 1,
                      'array_slice' => 1,
                      'swf_mulcolor' => 1,
                      'yp_match' => 1,
                      'hw_getobjectbyqueryobj' => 1,
                      'pfpro_process' => 1,
                      'sesam_field_name' => 1,
                      'ibase_execute' => 1,
                      'mcal_event_set_recur_weekly' => 1,
                      'create_function' => 1,
                      'frenchtojd' => 1,
                      'mysql_field_len' => 1,
                      'substr' => 1,
                      'arsort' => 1,
                      'natcasesort' => 1,
                      'mcrypt_enc_get_supported_key_sizes' => 1,
                      'bcsqrt' => 1,
                      'imap_mail_compose' => 1,
                      'imagepstext' => 1,
                      'pdf_fill_stroke' => 1,
                      'filegroup' => 1,
                      'ovrimos_field_type' => 1,
                      'hw_connect' => 1,
                      'sybase_min_message_severity' => 1,
                      'getservbyname' => 1,
                      'hw_free_document' => 1,
                      'htmlentities' => 1,
                      'jdtogregorian' => 1,
                      'hw_document_size' => 1,
                      'cpdf_fill' => 1,
                      'openssl_get_privatekey' => 1,
                      'ovrimos_cursor' => 1,
                      'mcal_close' => 1,
                      'ifx_getsqlca' => 1,
                      'mysql_free_result' => 1,
                      'ifx_prepare' => 1,
                      'mysql_create_db' => 1,
                      'quoted_printable_decode' => 1,
                      'gethostbyname' => 1,
                      'ftp_nlist' => 1,
                      'ifx_do' => 1,
                      'ibase_prepare' => 1,
                      'pg_loopen' => 1,
                      'pg_put_line' => 1,
                      'pg_port' => 1,
                      'mcrypt_get_block_size' => 1,
                      'is_resource' => 1,
                      'array_diff' => 1,
                      'ifxus_write_slob' => 1,
                      'ingres_rollback' => 1,
                      'mssql_pconnect' => 1,
                      'swf_oncondition' => 1,
                      'gmp_scan0' => 1,
                      'apache_note' => 1,
                      'restore_error_handler' => 1,
                      'cpdf_setlinecap' => 1,
                      'ftp_login' => 1,
                      'sesam_rollback' => 1,
                      'mcal_list_events' => 1,
                      'imagegammacorrect' => 1,
                      'imap_rfc822_parse_headers' => 1,
                      'asort' => 1,
                      'textdomain' => 1,
                      'ovrimos_field_len' => 1,
                      'ldap_get_values_len' => 1,
                      'mcrypt_get_cipher_name' => 1,
                      'array_merge' => 1,
                      'ifx_create_char' => 1,
                      'imagecolortransparent' => 1,
                      'microtime' => 1,
                      'cpdf_save_to_file' => 1,
                      'strip_tags' => 1,
                      'ingres_close' => 1,
                      'ocicolumnisnull' => 1,
                      'sesam_seek_row' => 1,
                      'cpdf_finalize' => 1,
                      'dbmfetch' => 1,
                      'mcal_fetch_event' => 1,
                      'mysql_affected_rows' => 1,
                      'gmdate' => 1,
                      'ovrimos_field_num' => 1,
                      'imagewbmp' => 1,
                      'array_values' => 1,
                      'xml_parser_get_option' => 1,
                      'mcal_time_valid' => 1,
                      'hw_getanchors' => 1,
                      'session_encode' => 1,
                      'pdf_end_page' => 1,
                      'readline_read_history' => 1,
                      'isset' => 1,
                      'sybase_fetch_row' => 1,
                      'imagepsloadfont' => 1,
                      'mysql_close' => 1,
                      'msql_create_db' => 1,
                      'gmp_invert' => 1,
                      'pos' => 1,
                      'shm_detach' => 1,
                      'pdf_set_parameter' => 1,
                      'mcrypt_enc_is_block_algorithm' => 1,
                      'posix_ctermid' => 1,
                      'preg_grep' => 1,
                      'ora_rollback' => 1,
                      'msql_listtables' => 1,
                      'imagefilledrectangle' => 1,
                      'pclose' => 1,
                      'fdf_set_status' => 1,
                      'addslashes' => 1,
                      'pg_fieldtype' => 1,
                      'max' => 1,
                      'is_dir' => 1,
                      'swf_getframe' => 1,
                      'soundex' => 1,
                      'fsockopen' => 1,
                      'mcrypt_module_open' => 1,
                      'xslt_transform' => 1,
                      'pdf_set_border_style' => 1,
                      'imap_getmailboxes' => 1,
                      'strspn' => 1,
                      'sesam_commit' => 1,
                      'exec' => 1,
                      'posix_getpwnam' => 1,
                      'odbc_exec' => 1,
                      'xml_set_object' => 1,
                      'swf_actionwaitforframe' => 1,
                      'imap_utf7_decode' => 1,
                      'mysql_fetch_assoc' => 1,
                      'filesize' => 1,
                      'session_decode' => 1,
                      'hw_document_content' => 1,
                      'convert_cyr_string' => 1,
                      'pg_set_client_encoding' => 1,
                      'cpdf_show' => 1,
                      'imap_fetchstructure' => 1,
                      'substr_replace' => 1,
                      'swf_actionsettarget' => 1,
                      'session_unregister' => 1,
                      'ob_end_flush' => 1,
                      'is_writable' => 1,
                      'swf_endsymbol' => 1,
                      'swf_endshape' => 1,
                      'ora_exec' => 1,
                      'get_parent_class' => 1,
                      'swf_actiontogglequality' => 1,
                      'ibase_num_fields' => 1,
                      'hw_info' => 1,
                      'method_exists' => 1,
                      'sesam_num_fields' => 1,
                      'ifx_free_char' => 1,
                      'gmp_random' => 1,
                      'fgetcsv' => 1,
                      'symlink' => 1,
                      'aspell_check' => 1,
                      'msql_fieldtype' => 1,
                      'hw_new_document' => 1,
                      'posix_getpwuid' => 1,
                      'ingres_field_scale' => 1,
                      'pdf_open_image_file' => 1,
                      'msql_fetch_object' => 1,
                      'ocirowcount' => 1,
                      'hw_mapid' => 1,
                      'jewishtojd' => 1,
                      'strerror' => 1,
                      'dbmclose' => 1,
                      'syslog' => 1,
                      'gzcompress' => 1,
                      'pdf_fill' => 1,
                      'is_link' => 1,
                      'debugger_on' => 1,
                      'gettext' => 1,
                      'file' => 1,
                      'explode' => 1,
                      'ifx_htmltbl_result' => 1,
                      'dbase_pack' => 1,
                      'error_reporting' => 1,
                      'is_integer' => 1,
                      'pg_dbname' => 1,
                      'easter_days' => 1,
                      'rename' => 1,
                      'yp_order' => 1,
                      'cpdf_continue_text' => 1,
                      'pg_fetch_array' => 1,
                      'getallheaders' => 1,
                      'ifx_update_char' => 1,
                      'posix_getppid' => 1,
                      'ldap_bind' => 1,
                      'swf_ortho2' => 1,
                      'msql_fieldlen' => 1,
                      'connection_aborted' => 1,
                      'socket_get_status' => 1,
                      'fdf_next_field_name' => 1,
                      'swf_definefont' => 1,
                      'get_class_methods' => 1,
                      'gzopen' => 1,
                      'openssl_open' => 1,
                      'gmp_hamdist' => 1,
                      'getmypid' => 1,
                      'ob_end_clean' => 1,
                      'mssql_fetch_object' => 1,
                      'swf_actiongotolabel' => 1,
                      'odbc_result_all' => 1,
                      'ovrimos_result' => 1,
                      'cpdf_lineto' => 1,
                      'strstr' => 1,
                      'xml_parser_free' => 1,
                      'gmp_div_r' => 1,
                      'cpdf_setrgbcolor_fill' => 1,
                      'hw_insertobject' => 1,
                      'getprotobynumber' => 1,
                      'gzfile' => 1,
                      'strcmp' => 1,
                      'odbc_num_rows' => 1,
                      'odbc_fetch_row' => 1,
                      'mcal_date_valid' => 1,
                      'orbitobject' => 1,
                      'pdf_stroke' => 1,
                      'msql_fieldflags' => 1,
                      'pdf_continue_text' => 1,
                      'iptcparse' => 1,
                      'msql_list_dbs' => 1,
                      'dbase_numrecords' => 1,
                      'mcal_rename_calendar' => 1,
                      'gmp_popcount' => 1,
                      'gmp_gcd' => 1,
                      'mcal_next_recurrence' => 1,
                      'gmp_xor' => 1,
                      'fgets' => 1,
                      'next' => 1,
                      'assert' => 1,
                      'get_magic_quotes_runtime' => 1,
                      'dba_popen' => 1,
                      'ldap_next_attribute' => 1,
                      'hw_insertdocument' => 1,
                      'pg_loclose' => 1,
                      'ip2long' => 1,
                      'mcrypt_module_is_block_algorithm_mode' => 1,
                      'ftp_get' => 1,
                      'ifx_fetch_row' => 1,
                      'sybase_num_rows' => 1,
                      'swf_shapefillbitmapclip' => 1,
                      'imagecreate' => 1,
                      'pdf_clip' => 1,
                      'imap_mail_move' => 1,
                      'php_sapi_name' => 1,
                      'cpdf_add_outline' => 1,
                      'ocifreecursor' => 1,
                      'cpdf_rect' => 1,
                      'pdf_show_boxed' => 1,
                      'mcrypt_enc_is_block_algorithm_mode' => 1,
                      'strtr' => 1,
                      'openlog' => 1,
                      'ldap_error' => 1,
                      'imap_num_recent' => 1,
                      'filetype' => 1,
                      'sybase_select_db' => 1,
                      'usleep' => 1,
                      'posix_setgid' => 1,
                      'cpdf_text' => 1,
                      'gzclose' => 1,
                      'ereg_replace' => 1,
                      'getmxrr' => 1,
                      'setcookie' => 1,
                      'bin2hex' => 1,
                      'swf_actiongeturl' => 1,
                      'ovrimos_num_fields' => 1,
                      'ucwords' => 1,
                      'gmp_clrbit' => 1,
                      'strncmp' => 1,
                      'fgetc' => 1,
                      'msql_select_db' => 1,
                      'swf_getfontinfo' => 1,
                      'spliti' => 1,
                      'xmltree' => 1,
                      'pspell_suggest' => 1,
                      'imap_headers' => 1,
                      'get_class_vars' => 1,
                      'ibase_field_info' => 1,
                      'cpdf_circle' => 1,
                      'pg_loimport' => 1,
                      'ibase_pconnect' => 1,
                      'yaz_record' => 1,
                      'imagecolorstotal' => 1,
                      'mysql_query' => 1,
                      'ifx_blobinfile_mode' => 1,
                      'ftp_chdir' => 1,
                      'sesam_fetch_array' => 1,
                      'get_class' => 1,
                      'deg2rad' => 1,
                      'pg_errormessage' => 1,
                      'imagecopyresized' => 1,
                      'mysql_fetch_lengths' => 1,
                      'dbase_get_record_with_names' => 1,
                      'pdf_close' => 1,
                      'ldap_list' => 1,
                      'swf_popmatrix' => 1,
                      'chown' => 1,
                      'ocifreestatement' => 1,
                      'ftp_fput' => 1,
                      'recode' => 1,
                      'xml_parser_set_option' => 1,
                      'cpdf_set_char_spacing' => 1,
                      'bccomp' => 1,
                      'mssql_select_db' => 1,
                      'unpack' => 1,
                      'imagepsslantfont' => 1,
                      'swf_openfile' => 1,
                      'swf_setframe' => 1,
                      'msql_close' => 1,
                      'xslt_output_begintransform' => 1,
                      'xml_parse' => 1,
                      'snmpset' => 1,
                      'posix_getrlimit' => 1,
                      'mcrypt_get_key_size' => 1,
                      'gmp_gcdext' => 1,
                      'ftp_quit' => 1,
                      'sql_regcase' => 1,
                      'com_propset' => 1,
                      'mcal_event_add_attribute' => 1,
                      'fileinode' => 1,
                      'ingres_commit' => 1,
                      'dbmexists' => 1,
                      'filepro_fieldcount' => 1,
                      'msql_fetch_array' => 1,
                      'msql_connect' => 1,
                      'hebrev' => 1,
                      'htmlspecialchars' => 1,
                      'pdf_open_png' => 1,
                      'mdecrypt_generic' => 1,
                      'imap_fetch_overview' => 1,
                      'imagerectangle' => 1,
                      'dgettext' => 1,
                      'read_exif_data' => 1,
                      'dbase_get_record' => 1,
                      'jdtounix' => 1,
                      'curl_setopt' => 1,
                      'ifxus_close_slob' => 1,
                      'bind' => 1,
                      'session_name' => 1,
                      'is_bool' => 1,
                      'session_start' => 1,
                      'fdf_open' => 1,
                      'imap_num_msg' => 1,
                      'yaz_addinfo' => 1,
                      'ceil' => 1,
                      'tmpfile' => 1,
                      'imap_append' => 1,
                      'levenshtein' => 1,
                      'gmp_or' => 1,
                      'serialize' => 1,
                      'mcal_delete_event' => 1,
                      'imap_rfc822_write_address' => 1,
                      'imagefontheight' => 1,
                      'fstat' => 1,
                      'reset' => 1,
                      'preg_replace' => 1,
                      'cpdf_rlineto' => 1,
                      'icap_close' => 1,
                      'connect' => 1,
                      'ora_logon' => 1,
                      'hw_getobjectbyquerycoll' => 1,
                      'link' => 1,
                      'mysql_num_fields' => 1,
                      'hw_output_document' => 1,
                      'prev' => 1,
                      'gmp_strval' => 1,
                      'swf_definerect' => 1,
                      'strtok' => 1,
                      'is_double' => 1,
                      'clearstatcache' => 1,
                      'wddx_packet_end' => 1,
                      'cybercash_base64_encode' => 1,
                      'diskfreespace' => 1,
                      'sleep' => 1,
                      'imagecolordeallocate' => 1,
                      'ifx_fieldtypes' => 1,
                      'print' => 1,
                      'ovrimos_close_all' => 1,
                      'mcrypt_list_algorithms' => 1,
                      'odbc_num_fields' => 1,
                      'ingres_autocommit' => 1,
                      'pg_options' => 1,
                      'cpdf_stringwidth' => 1,
                      'getenv' => 1,
                      'ldap_unbind' => 1,
                      'hw_inscoll' => 1,
                      'gzgetc' => 1,
                      'imagecolorsforindex' => 1,
                      'getlastmod' => 1,
                      'odbc_field_type' => 1,
                      'com_propput' => 1,
                      'imap_uid' => 1,
                      'ifx_num_fields' => 1,
                      'openssl_get_publickey' => 1,
                      'cpdf_curveto' => 1,
                      'cybercash_encr' => 1,
                      'ibase_query' => 1,
                      'uksort' => 1,
                      'ftp_size' => 1,
                      'mcrypt_ofb' => 1,
                      'dba_optimize' => 1,
                      'array_pop' => 1,
                      'msql_affected_rows' => 1,
                      'imagecreatefromgif' => 1,
                      'msql_fieldname' => 1,
                      'msql_freeresult' => 1,
                      'is_float' => 1,
                      'swf_shapefillsolid' => 1,
                      'popen' => 1,
                      'xslt_free' => 1,
                      'strncasecmp' => 1,
                      'msql_num_rows' => 1,
                      'number_format' => 1,
                      'pdf_open_jpeg' => 1,
                      'dba_close' => 1,
                      'extract' => 1,
                      'ldap_dn2ufn' => 1,
                      'ldap_compare' => 1,
                      'pfsockopen' => 1,
                      'mcal_event_set_recur_none' => 1,
                      'hw_pconnect' => 1,
                      'posix_uname' => 1,
                      'bcsub' => 1,
                      'odbc_field_num' => 1,
                      'readdir' => 1,
                      'gzeof' => 1,
                      'posix_getlogin' => 1,
                      'swf_polarview' => 1,
                      'ovrimos_result_all' => 1,
                      'cpdf_set_keywords' => 1,
                      'cpdf_moveto' => 1,
                      'ftp_connect' => 1,
                      'getrandmax' => 1,
                      'ifxus_open_slob' => 1,
                      'pg_host' => 1,
                      'cpdf_restore' => 1,
                      'odbc_pconnect' => 1,
                      'imap_listmailbox' => 1,
                      'imagecreatefrompng' => 1,
                      'extension_loaded' => 1,
                      'tempnam' => 1,
                      'filectime' => 1,
                      'imap_rfc822_parse_adrlist' => 1,
                      'wddx_packet_start' => 1,
                      'posix_kill' => 1,
                      'is_subclass_of' => 1,
                      'swf_actionstop' => 1,
                      'ini_get' => 1,
                      'unserialize' => 1,
                      'yp_first' => 1,
                      'sesam_fetch_row' => 1,
                      'orbitenum' => 1,
                      'array_walk' => 1,
                      'strcasecmp' => 1,
                      'swf_actionplay' => 1,
                      'imagejpeg' => 1,
                      'bcscale' => 1,
                      'sscanf' => 1,
                      'xslt_process' => 1,
                      'posix_getpid' => 1,
                      'mcal_date_compare' => 1,
                      'mt_getrandmax' => 1,
                      'cpdf_clip' => 1,
                      'settype' => 1,
                      'msql_numfields' => 1,
                      'pdf_set_word_spacing' => 1,
                      'cpdf_closepath_fill_stroke' => 1,
                      'curl_close' => 1,
                      'pg_locreate' => 1,
                      'mcal_event_set_title' => 1,
                      'fclose' => 1,
                      'mssql_query' => 1,
                      'aspell_suggest' => 1,
                      'mktime' => 1,
                      'msql_list_fields' => 1,
                      'urldecode' => 1,
                      'abs' => 1,
                      'imagecreatefromwbmp' => 1,
                      'xml_get_current_byte_index' => 1,
                      'ocibindbyname' => 1,
                      'hw_getparents' => 1,
                      'swf_endbutton' => 1,
                      'dba_insert' => 1,
                      'sesam_connect' => 1,
                      'fdf_close' => 1,
                      'gzgets' => 1,
                      'snmpget' => 1,
                      'swf_rotate' => 1,
                      'mcrypt_enc_get_algorithms_name' => 1,
                      'echo' => 1,
                      'mysql_db_query' => 1,
                      'pg_exec' => 1,
                      'imagechar' => 1,
                      'rawurldecode' => 1,
                      'session_save_path' => 1,
                      'is_real' => 1,
                      'sybase_close' => 1,
                      'ovrimos_prepare' => 1,
                      'ftp_rename' => 1,
                      'xslt_output_endtransform' => 1,
                      'odbc_rollback' => 1,
                      'mcal_days_in_month' => 1,
                      'mcal_event_init' => 1,
                      'sesam_field_array' => 1,
                      'mkdir' => 1,
                      'pdf_restore' => 1,
                      'fputs' => 1,
                      'posix_getgroups' => 1,
                      'cpdf_closepath' => 1,
                      'fileperms' => 1,
                      'ocicolumntype' => 1,
                      'decbin' => 1,
                      'sesam_query' => 1,
                      'mt_rand' => 1,
                      'cpdf_set_creator' => 1,
                      'pdf_setgray' => 1,
                      'pdf_setgray_stroke' => 1,
                      'strrpos' => 1,
                      'strchr' => 1,
                      'strftime' => 1,
                      'gzpassthru' => 1,
                      'ifx_free_result' => 1,
                      'gzgetss' => 1,
                      'srand' => 1,
                      'compact' => 1,
                      'error_log' => 1,
                      'gettimeofday' => 1,
                      'rawurlencode' => 1,
                      'gmp_sign' => 1,
                      'ifx_num_rows' => 1,
                      'swf_shapecurveto' => 1,
                      'phpversion' => 1,
                      'msql_fieldtable' => 1,
                      'readline_clear_history' => 1,
                      'yaz_hits' => 1,
                      'unixtojd' => 1,
                      'fdf_set_submit_form_action' => 1,
                      'pdf_put_image' => 1,
                      'fdf_get_file' => 1,
                      'cpdf_set_page_animation' => 1,
                      'imap_ping' => 1,
                      'hw_close' => 1,
                      'xmldocfile' => 1,
                      'dbmopen' => 1,
                      'imagegif' => 1,
                      'msql_listdbs' => 1,
                      'odbc_field_len' => 1,
                      'mcal_delete_calendar' => 1,
                      'ldap_delete' => 1,
                      'var_dump' => 1,
                      'dbase_delete_record' => 1,
                      'icap_delete_event' => 1,
                      'pdf_lineto' => 1,
                      'pdf_setlinecap' => 1,
                      'ldap_mod_add' => 1,
                      'rewind' => 1,
                      'get_cfg_var' => 1,
                      'imap_mime_header_decode' => 1,
                      'imap_mailboxmsginfo' => 1,
                      'imagettfbbox' => 1,
                      'pspell_add_to_session' => 1,
                      'swf_addbuttonrecord' => 1,
                      'gmp_pow' => 1,
                      'mysql_fetch_row' => 1,
                      'odbc_autocommit' => 1,
                      'hw_docbyanchorobj' => 1,
                      'key' => 1,
                      'gmp_sqrtrm' => 1,
                      'pdf_set_text_rise' => 1,
                      'mysql_field_flags' => 1,
                      'chop' => 1,
                      'swf_posround' => 1,
                      'mcal_list_alarms' => 1,
                      'ezmlm_hash' => 1,
                      'gmp_abs' => 1,
                      'satellite_exception_value' => 1,
                      'hw_getobject' => 1,
                      'ifx_fieldproperties' => 1,
                      'ingres_fetch_array' => 1,
                      'icap_open' => 1,
                      'yaz_error' => 1,
                      'com_set' => 1,
                      'swf_shapemoveto' => 1,
                      'php_logo_guid' => 1,
                      'mcrypt_cbc' => 1,
                      'krsort' => 1,
                      'ovrimos_longreadlen' => 1,
                      'hw_who' => 1,
                      'curl_init' => 1,
                      'sem_acquire' => 1,
                      'mysql_list_dbs' => 1,
                      'cpdf_fill_stroke' => 1,
                      'touch' => 1,
                      'yp_get_default_domain' => 1,
                      'ociparse' => 1,
                      'cybercash_decr' => 1,
                      'linkinfo' => 1,
                      'xml_get_error_code' => 1,
                      'readfile' => 1,
                      'die' => 1,
                      'mhash_get_block_size' => 1,
                      'xml_set_default_handler' => 1,
                      'mysql_db_name' => 1,
                      'ascii2ebcdic' => 1,
                      'msql_pconnect' => 1,
                      'ociinternaldebug' => 1,
                      'array_rand' => 1,
                      'mysql_list_fields' => 1,
                      'odbc_setoption' => 1,
                      'pdf_set_text_rendering' => 1,
                      'hw_getremote' => 1,
                      'imap_headerinfo' => 1,
                      'mcal_is_leap_year' => 1,
                      'pspell_config_personal' => 1,
                      'ovrimos_execute' => 1,
                      'imap_msgno' => 1,
                      'pdf_close_image' => 1,
                      'mcal_event_set_start' => 1,
                      'pdf_open' => 1,
                      'ifx_connect' => 1,
                      'hw_getobjectbyquery' => 1,
                      'posix_getpgrp' => 1,
                      'pdf_skew' => 1,
                      'exit' => 1,
                      'xml_set_unparsed_entity_decl_handler' => 1,
                      'swf_labelframe' => 1,
                      'swf_pushmatrix' => 1,
                      'mcrypt_cfb' => 1,
                      'imap_createmailbox' => 1,
                      'gettype' => 1,
                      'dba_nextkey' => 1,
                      'write' => 1,
                      'func_num_args' => 1,
                      'ftp_pwd' => 1,
                      'readline_write_history' => 1,
                      'swf_shapefillbitmaptile' => 1,
                      'pack' => 1,
                      'strcspn' => 1,
                      'pg_freeresult' => 1,
                      'pdf_moveto' => 1,
                      'mysql_insert_id' => 1,
                      'swf_setfont' => 1,
                      'shm_attach' => 1,
                      'mcal_event_set_recur_monthly_wday' => 1,
                      'ldap_get_attributes' => 1,
                      'strrev' => 1,
                      'printf' => 1,
                      'pdf_circle' => 1,
                      'mcrypt_generic_end' => 1,
                      'pdf_stringwidth' => 1,
                      'gzseek' => 1,
                      'mssql_field_seek' => 1,
                      'ibase_free_query' => 1,
                      'imagetypes' => 1,
                      'is_numeric' => 1,
                      'sybase_fetch_array' => 1,
                      'ocirollback' => 1,
                      'urlencode' => 1,
                      'pdf_setlinejoin' => 1,
                      'ifxus_seek_slob' => 1,
                      'hw_childrenobj' => 1,
                      'pfpro_process_raw' => 1,
                      'mysql_connect' => 1,
                      'dbase_replace_record' => 1,
                      'icap_fetch_event' => 1,
                      'ini_alter' => 1,
                      'ocicommit' => 1,
                      'mssql_fetch_field' => 1,
                      'func_get_arg' => 1,
                      'ftp_site' => 1,
                      'setlocale' => 1,
                      'stripcslashes' => 1,
                      'filepro_fieldname' => 1,
                      'dblist' => 1,
                      'imagedestroy' => 1,
                      'pdf_setrgbcolor_fill' => 1,
                      'mysql_pconnect' => 1,
                      'xslt_closelog' => 1,
                      'mssql_get_last_message' => 1,
                      'cpdf_set_text_rise' => 1,
                      'pdf_setdash' => 1,
                      'cpdf_setgray' => 1,
                      'yaz_range' => 1,
                      'hw_identify' => 1,
                      'sybase_free_result' => 1,
                      'mssql_connect' => 1,
                      'swf_modifyobject' => 1,
                      'pspell_store_replacement' => 1,
                      'pfpro_cleanup' => 1,
                      'hw_array2objrec' => 1,
                      'dbase_add_record' => 1,
                      'xslt_openlog' => 1,
                      'leak' => 1,
                      'dbminsert' => 1,
                      'ldap_modify' => 1,
                      'ftruncate' => 1,
                      'dbase_create' => 1,
                      'mssql_num_rows' => 1,
                      'gzwrite' => 1,
                      'ucfirst' => 1,
                      'hw_getremotechildren' => 1,
                      'imagefilltoborder' => 1,
                      'shm_remove_var' => 1,
                      'pspell_clear_session' => 1,
                      'ldap_count_entries' => 1,
                      'rmdir' => 1,
                      'cpdf_set_text_rendering' => 1,
                      'strpos' => 1,
                      'pdf_get_image_width' => 1,
                      'ifx_update_blob' => 1,
                      'checkdate' => 1,
                      'posix_setuid' => 1,
                      'imap_body' => 1,
                      'imap_undelete' => 1,
                      'readlink' => 1,
                      'hw_getchildcoll' => 1,
                      'unset' => 1,
                      'ociserverversion' => 1,
                      'ldap_get_dn' => 1,
                      'pg_connect' => 1,
                      'dba_fetch' => 1,
                      'get_object_vars' => 1,
                      'msql_listfields' => 1,
                      'pg_lowrite' => 1,
                      'mcrypt_decrypt' => 1,
                      'pdf_open_gif' => 1,
                      'ibase_fetch_row' => 1,
                      'com_load' => 1,
                      'empty' => 1,
                      'pi' => 1,
                      'mail' => 1,
                      'hw_getsrcbydestobj' => 1,
                      'eval' => 1,
                      'gmp_div_qr' => 1,
                      'sesam_disconnect' => 1,
                      'socket_set_blocking' => 1,
                      'ingres_field_name' => 1,
                      'shm_put_var' => 1,
                      'pdf_set_transition' => 1,
                      'swf_viewport' => 1,
                      'wddx_add_vars' => 1,
                      'gmp_sqrt' => 1,
                      'array_pad' => 1,
                      'pdf_closepath_stroke' => 1,
                      'pdf_set_info' => 1,
                      'stripslashes' => 1,
                      'imap_listsubscribed' => 1,
                      'date' => 1,
                      'msql_field_seek' => 1,
                      'xml_set_external_entity_ref_handler' => 1,
                      'is_array' => 1,
                      'swf_shapearc' => 1,
                      'ftp_mdtm' => 1,
                      'cpdf_show_xy' => 1,
                      'fopen' => 1,
                      'pdf_set_font' => 1,
                      'snmp_set_quick_print' => 1,
                      'gzputs' => 1,
                      'xml_get_current_line_number' => 1,
                      'crc32' => 1,
                      'imap_errors' => 1,
                      'pg_fieldname' => 1,
                      'imagestring' => 1,
                      'dba_replace' => 1,
                      'stat' => 1,
                      'ibase_errmsg' => 1,
                      'readline_add_history' => 1,
                      'mysql_fetch_field' => 1,
                      'swf_definebitmap' => 1,
                      'ingres_num_fields' => 1,
                      'mcal_expunge' => 1,
                      'pg_client_encoding' => 1,
                      'headers_sent' => 1,
                      'session_id' => 1,
                      'posix_mkfifo' => 1,
                      'cpdf_set_horiz_scaling' => 1,
                      'system' => 1,
                      'hw_objrec2array' => 1,
                      'mcrypt_encrypt' => 1,
                      'dir' => 1,
                      'getprotobyname' => 1,
                      'sybase_fetch_field' => 1,
                      'rad2deg' => 1,
                      'sesam_affected_rows' => 1,
                      'imagefill' => 1,
                      'imap_utf8' => 1,
                      'ord' => 1,
                      'array_unshift' => 1,
                      'imap_delete' => 1,
                      'mt_srand' => 1,
                      'fdf_get_value' => 1,
                      'connection_status' => 1,
                      'virtual' => 1,
                      'msql_list_tables' => 1,
                      'shm_get_var' => 1,
                      'mcrypt_enc_is_block_mode' => 1,
                      'mssql_field_name' => 1,
                      'session_get_cookie_params' => 1,
                      'msql_result' => 1,
                      'ora_numcols' => 1,
                      'yaz_connect' => 1,
                      'cpdf_closepath_stroke' => 1,
                      'utf8_decode' => 1,
                      'pg_fieldisnull' => 1,
                      'pdf_set_border_color' => 1,
                      'gmmktime' => 1,
                      'cpdf_setrgbcolor' => 1,
                      'substr_count' => 1,
                      'cpdf_global_set_document_limits' => 1,
                      'icap_store_event' => 1,
                      'hw_document_bodytag' => 1,
                      'exp' => 1,
                      'ovrimos_num_rows' => 1,
                      'jddayofweek' => 1,
                      'hw_deleteobject' => 1,
                      'hw_incollections' => 1,
                      'imap_setflag_full' => 1,
                      'ora_commit' => 1,
                      'pdf_closepath' => 1,
                      'mcal_popen' => 1,
                      'str_replace' => 1,
                      'gmp_perfect_square' => 1,
                      'sybase_min_error_severity' => 1,
                      'putenv' => 1,
                      'imap_status' => 1,
                      'posix_isatty' => 1,
                      'posix_getgid' => 1,
                      'xslt_create' => 1,
                      'gmp_jacobi' => 1,
                      'hw_insdoc' => 1,
                      'fdf_get_status' => 1,
                      'mcrypt_module_get_algo_key_size' => 1,
                      'zend_logo_guid' => 1,
                      'array_unique' => 1,
                      'ingres_query' => 1,
                      'fread' => 1,
                      'mcrypt_enc_get_iv_size' => 1,
                      'mysql_list_tables' => 1,
                      'ldap_errno' => 1,
                      'uniqid' => 1,
                      'ora_columnsize' => 1,
                      'imap_utf7_encode' => 1,
                      'odbc_do' => 1,
                      'pdf_add_outline' => 1,
                      'atan2' => 1,
                      'msql_dbname' => 1,
                      'odbc_gettypeinfo' => 1,
                      'swf_showframe' => 1,
                      'mhash_keygen_s2k' => 1,
                      'readline_list_history' => 1,
                      'closedir' => 1,
                      'get_magic_quotes_gpc' => 1,
                      'ora_fetch' => 1,
                      'mcal_day_of_week' => 1,
                      'getservbyport' => 1,
                      'cpdf_arc' => 1,
                      'atan' => 1,
                      'swf_translate' => 1,
                      'swf_perspective' => 1,
                      'gmp_legendre' => 1,
                      'mcrypt_module_get_algo_supported_key_sizes' => 1,
                      'odbc_statistics' => 1,
                      'get_declared_classes' => 1,
                      'xmldoc' => 1,
                      'sybase_min_server_severity' => 1,
                      'swf_shapelinesolid' => 1,
                      'ifx_create_blob' => 1,
                      'msql_selectdb' => 1,
                      'shmop_open' => 1,
                      'curl_version' => 1,
                      'ignore_user_abort' => 1,
                      'ifx_get_blob' => 1,
                      'pdf_get_image_height' => 1,
                      'ocinumcols' => 1,
                      'session_unset' => 1,
                      'assert_options' => 1,
                      'strlen' => 1,
                      'imap_scanmailbox' => 1,
                      'call_user_func' => 1,
                      'call_user_method' => 1,
                      'xml_set_character_data_handler' => 1,
                      'asin' => 1,
                      'pdf_setgray_fill' => 1,
                      'fscanf' => 1,
                      'odbc_foreignkeys' => 1,
                      'chr' => 1,
                      'hw_getchildcollobj' => 1,
                      'cpdf_stroke' => 1,
                      'odbc_columns' => 1,
                      'hw_error' => 1,
                      'wordwrap' => 1,
                      'aspell_check_raw' => 1,
                      'cpdf_setgray_stroke' => 1,
                      'mysql_select_db' => 1,
                      'lstat' => 1,
                      'accept_connect' => 1,
                      'recode_file' => 1,
                      'fdf_set_file' => 1,
                      'mssql_fetch_row' => 1,
                      'ora_fetch_into' => 1,
                      'sybase_fetch_object' => 1,
                      'swf_shapelineto' => 1,
                      'cpdf_scale' => 1,
                      'is_file' => 1,
                      'ldap_get_values' => 1,
                      'ocicolumnsize' => 1,
                      'ksort' => 1,
                      'sizeof' => 1,
                      'hw_getchilddoccollobj' => 1,
                      'pg_loread' => 1,
                      'satellite_caught_exception' => 1,
                      'defined' => 1,
                      'posix_getcwd' => 1,
                      'mcal_snooze' => 1,
                      'cpdf_place_inline_image' => 1,
                      'odbc_connect' => 1,
                      'posix_getegid' => 1,
                      'hw_modifyobject' => 1,
                      'ftp_rmdir' => 1,
                      'xslt_set_sax_handler' => 1,
                      'pdf_arc' => 1,
                      'cpdf_setlinewidth' => 1,
                      'base_convert' => 1,
                      'move_uploaded_file' => 1,
                      'gmp_mul' => 1,
                      'dechex' => 1,
                      'imap_last_error' => 1,
                      'gzread' => 1,
                      'dcgettext' => 1,
                      'ldap_err2str' => 1,
                      'ora_getcolumn' => 1,
                      'log10' => 1,
                      'readline_info' => 1,
                      'pdf_curveto' => 1,
                      'log' => 1,
                      'cpdf_open' => 1,
                      'is_object' => 1,
                      'cpdf_save' => 1,
                      'preg_match_all' => 1,
                      'sybase_pconnect' => 1,
                      'imap_fetchheader' => 1,
                      'ocifetch' => 1,
                      'pow' => 1,
                      'msql_tablename' => 1,
                      'imageloadfont' => 1,
                      'sesam_diagnostic' => 1,
                      'imagesx' => 1,
                      'imap_fetchbody' => 1,
                      'shmop_delete' => 1,
                      'session_module_name' => 1,
                      'ociresult' => 1,
                      'str_repeat' => 1,
                      'bcmul' => 1,
                      'icap_list_alarms' => 1,
                      'ovrimos_free_result' => 1,
                      'count_chars' => 1,
                      'xml_set_element_handler' => 1,
                      'mysql_error' => 1,
                      'gmp_div' => 1,
                      'dba_sync' => 1,
                      'set_error_handler' => 1,
                      'filepro_retrieve' => 1,
                      'trim' => 1,
                      'swf_startsymbol' => 1,
                      'nl2br' => 1,
                      'cpdf_setflat' => 1,
                      'ociplogon' => 1,
                      'shm_remove' => 1,
                      'imap_reopen' => 1,
                      'delete' => 1,
                      'pdf_save' => 1,
                      'ifx_get_char' => 1,
                      'imagepsfreefont' => 1,
                      'ovrimos_field_name' => 1,
                      'imageline' => 1,
                      'pg_close' => 1,
                      'ftp_fget' => 1,
                      'mcal_reopen' => 1,
                      'mcal_fetch_current_stream_event' => 1,
                      'hw_gettext' => 1,
                      'gmp_neg' => 1,
                      'pdf_setrgbcolor' => 1,
                      'pdf_setmiterlimit' => 1,
                      'shuffle' => 1,
                      'imagearc' => 1,
                      'hw_getanchorsobj' => 1,
                      'hw_getandlock' => 1,
                      'pdf_get_value' => 1,
                      'ifxus_tell_slob' => 1,
                      'ldap_set_option' => 1,
                      'swf_actionnextframe' => 1,
                      'pg_cmdtuples' => 1,
                      'swf_nextid' => 1,
                      'pdf_show' => 1,
                      'sort' => 1,
                      'fpassthru' => 1,
                      'odbc_tableprivileges' => 1,
                      'sem_release' => 1,
                      'fgetss' => 1,
                      'pdf_add_annotation' => 1,
                      'gmstrftime' => 1,
                      'ftp_pasv' => 1,
                      'recode_string' => 1,
                      'ftell' => 1,
                      'hw_errormsg' => 1,
                      'imagesetpixel' => 1,
                      'strtoupper' => 1,
                      'gmp_scan1' => 1,
                      'ob_get_contents' => 1,
                      'pdf_setflat' => 1,
                      'wddx_serialize_vars' => 1,
                      'strtolower' => 1,
                      'pg_pconnect' => 1,
                      'unlink' => 1,
                      'mssql_min_message_severity' => 1,
                      'sybase_data_seek' => 1,
                      'pg_loexport' => 1,
                      'pdf_set_duration' => 1,
                      'get_browser' => 1,
                      'split' => 1,
                      'pspell_add_to_personal' => 1,
                      'xml_parse_into_struct' => 1,
                      'com_get' => 1,
                      'ociexecute' => 1,
                      'addcslashes' => 1,
                      'com_propget' => 1,
                      'posix_getpgid' => 1,
                      'is_int' => 1,
                      'dba_firstkey' => 1,
                      'mcal_event_set_category' => 1,
                      'fdf_save' => 1,
                      'ocifetchinto' => 1,
                      'ovrimos_fetch_row' => 1,
                      'gmp_div_q' => 1,
                      'session_is_registered' => 1,
                      'ebcdic2ascii' => 1,
                      'swf_shapecurveto3' => 1,
                      'pdf_closepath_fill_stroke' => 1,
                      'swf_definetext' => 1,
                      'imagepolygon' => 1,
                      'file_exists' => 1,
                      'ocistatementtype' => 1,
                      'pdf_set_text_pos' => 1,
                      'usort' => 1,
                      'imagecopy' => 1,
                      'odbc_free_result' => 1,
                      'pdf_show_xy' => 1,
                      'getimagesize' => 1,
                      'highlight_file' => 1,
                      'getmyuid' => 1,
                      'ifx_error' => 1,
                      'ibase_fetch_object' => 1,
                      'ocifreedesc' => 1,
                      'ereg' => 1,
                      'posix_setpgid' => 1,
                      'imap_expunge' => 1,
                      'posix_geteuid' => 1,
                      'pdf_setlinewidth' => 1,
                      'sesam_fetch_result' => 1,
                      'swf_enddoaction' => 1,
                      'gmp_init' => 1,
                      'hw_document_setcontent' => 1,
                      'imap_alerts' => 1,
                      'highlight_string' => 1,
                      'gzuncompress' => 1,
                      'msql_free_result' => 1,
                      'filepro_rowcount' => 1,
                      'eregi' => 1,
                      'bcadd' => 1,
                      'gztell' => 1,
                      'orbitstruct' => 1,
                      'cpdf_setmiterlimit' => 1,
                      'mssql_free_result' => 1,
                      'mcal_append_event' => 1,
                      'icap_snooze' => 1,
                      'mcrypt_ecb' => 1,
                      'ibase_timefmt' => 1,
                      'ini_restore' => 1,
                      'mcal_event_set_class' => 1,
                      'sesam_settransaction' => 1,
                      'join' => 1,
                      'ingres_fetch_object' => 1,
                      'mhash_get_hash_name' => 1,
                      'set_magic_quotes_runtime' => 1,
                      'strtotime' => 1,
                      'sybase_query' => 1,
                      'imap_mail' => 1,
                      'ingres_fetch_row' => 1,
                      'imageinterlace' => 1,
                      'octdec' => 1,
                      'snmpwalkoid' => 1,
                      'swf_startbutton' => 1,
                      'ocifetchstatement' => 1,
                      'phpinfo' => 1,
                      'imap_subscribe' => 1,
                      'xml_error_string' => 1,
                      'icap_list_events' => 1,
                      'gmp_powm' => 1,
                      'pg_numrows' => 1,
                      'ifxus_read_slob' => 1,
                      'rsort' => 1,
                      'msql_query' => 1,
                      'hebrevc' => 1,
                      'ifxus_free_slob' => 1,
                      'xml_set_notation_decl_handler' => 1,
                      'pspell_config_create' => 1,
                      'mcrypt_enc_self_test' => 1,
                      'wddx_deserialize' => 1,
                      'pdf_endpath' => 1,
                      'gethostbyaddr' => 1,
                      'mcrypt_generic_init' => 1,
                      'posix_times' => 1,
                      'ora_do' => 1,
                      'utf8_encode' => 1,
                      'get_html_translation_table' => 1,
                      'dbase_open' => 1,
                      'checkdnsrr' => 1,
                      'mcrypt_enc_get_key_size' => 1,
                      'yaz_search' => 1,
                      'cpdf_close' => 1,
                      'ibase_connect' => 1,
                      'read' => 1,
                      'ob_start' => 1,
                      'msql_dropdb' => 1,
                      'shmop_read' => 1,
                      'ldap_free_result' => 1,
                      'pdf_scale' => 1,
                      'imap_search' => 1,
                      'ora_errorcode' => 1,
                      'socket' => 1,
                      'pdf_open_tiff' => 1,
                      'end' => 1,
                      'curl_exec' => 1,
                      'pdf_set_char_spacing' => 1,
                      'ftp_cdup' => 1,
                      'ingres_field_nullable' => 1,
                      'fileatime' => 1,
                      'function_exists' => 1,
                      'yp_next' => 1,
                      'dba_exists' => 1,
                      'mysql_num_rows' => 1,
                      'stristr' => 1,
                      'ldap_close' => 1,
                      'odbc_primarykeys' => 1,
                      'ldap_mod_replace' => 1,
                      'ora_close' => 1,
                      'current' => 1,
                      'pdf_set_text_matrix' => 1,
                      'mcrypt_get_iv_size' => 1,
                      'is_uploaded_file' => 1,
                      'sesam_errormsg' => 1,
                      'pg_getlastoid' => 1,
                      'msql_createdb' => 1,
                      'mysql_tablename' => 1,
                      'imagesy' => 1,
                      'is_readable' => 1,
                      'swf_defineline' => 1,
                      'jdtojewish' => 1,
                      'imap_open' => 1,
                      'odbc_binmode' => 1,
                      'floor' => 1,
                      'bcdiv' => 1,
                      'ingres_connect' => 1,
                      'array_multisort' => 1,
                      'cpdf_set_current_page' => 1,
                      'msql_data_seek' => 1,
                      'pg_numfields' => 1,
                      'imagepng' => 1,
                      'imap_8bit' => 1,
                      'mcal_event_set_alarm' => 1,
                      'pdf_set_value' => 1,
                      'ftp_delete' => 1,
                      'mcrypt_module_self_test' => 1,
                      'in_array' => 1,
                      'ora_columntype' => 1,
                      'cpdf_setrgbcolor_stroke' => 1,
                      'mcrypt_list_modes' => 1,
                      'msql_regcase' => 1,
                      'cpdf_setdash' => 1,
                      'mhash_count' => 1,
                      'xml_set_processing_instruction_handler' => 1,
                      'time' => 1,
                      'round' => 1,
                      'imap_qprint' => 1,
                      'pdf_translate' => 1,
                      'pdf_get_parameter' => 1,
                      'xslt_fetch_result' => 1,
                      'readline' => 1,
                      'ibase_close' => 1,
                      'odbc_execute' => 1,
                      'hw_mv' => 1,
                      'xslt_errno' => 1,
                      'array_flip' => 1,
                      'fflush' => 1,
                      'session_cache_limiter' => 1,
                      'chgrp' => 1,
                      'ora_commiton' => 1,
                      'xslt_run' => 1,
                      'pg_result' => 1,
                      'copy' => 1,
                      'ini_set' => 1,
                      'ifx_query' => 1,
                      'hw_getobjectbyquerycollobj' => 1,
                      'ovrimos_rollback' => 1,
                      'ora_parse' => 1,
                      'hw_children' => 1,
                      'ingres_num_rows' => 1,
                      'escapeshellarg' => 1,
                      'dbmfirstkey' => 1,
                      'mcal_day_of_year' => 1,
                      'mssql_result' => 1,
                      'odbc_cursor' => 1,
                      'ifx_affected_rows' => 1,
                      'ldap_first_attribute' => 1,
                      'mcal_create_calendar' => 1,
                      'mcrypt_enc_get_modes_name' => 1,
                      'swf_closefile' => 1,
                      'tan' => 1,
                      'openssl_free_key' => 1,
                      'swf_getbitmapinfo' => 1,
                      'print_r' => 1,
                      'pdf_open_memory_image' => 1,
                      'fdf_set_opt' => 1,
                      'cpdf_end_text' => 1,
                      'mcrypt_enc_get_block_size' => 1,
                      'readline_completion_function' => 1,
                      'mssql_data_seek' => 1,
                      'pg_trace' => 1,
                      'pg_fieldprtlen' => 1,
                      'session_set_cookie_params' => 1,
                      'ocidefinebyname' => 1,
                      'pspell_save_wordlist' => 1,
                      'com_invoke' => 1,
                      'imagepsbbox' => 1,
                      'odbc_longreadlen' => 1,
                      'similar_text' => 1,
                      'xml_get_current_column_number' => 1,
                      'ora_open' => 1,
                      'closelog' => 1,
                      'ingres_field_length' => 1,
                      'pg_lounlink' => 1,
                      'hw_document_attributes' => 1,
                      'ora_numrows' => 1,
                      'ovrimos_close' => 1,
                      'dbase_close' => 1,
                      'lcg_value' => 1,
                      'imagecreatefromstring' => 1,
                      'session_destroy' => 1,
                      'cpdf_output_buffer' => 1,
                      'mssql_num_fields' => 1,
                      'list' => 1,
                      'imap_mail_copy' => 1,
                      'trigger_error' => 1,
                      'cpdf_setgray_fill' => 1,
                      'is_string' => 1,
                      'ftp_systype' => 1,
                      'cpdf_add_annotation' => 1,
                      'ifx_free_blob' => 1,
                      'strval' => 1,
                      'ldap_get_entries' => 1,
                      'ldap_get_option' => 1,
                      'posix_ttyname' => 1,
                      'gmp_intval' => 1,
                      'swf_fonttracking' => 1,
                      'fwrite' => 1,
                      'sybase_num_fields' => 1,
                      'imap_sort' => 1,
                      'snmpwalk' => 1,
                      'array_reverse' => 1,
                      'intval' => 1,
                      'sybase_connect' => 1,
                      'yaz_close' => 1,
                      'swf_fontsize' => 1,
                      'swf_ortho' => 1,
                      'set_time_limit' => 1,
                      'ocicolumnname' => 1,
                      'odbc_procedures' => 1,
                      'filepro' => 1,
                      'mcal_event_set_recur_daily' => 1,
                      'ifxus_create_slob' => 1,
                      'ocilogoff' => 1,
                      'pspell_new_config' => 1,
                      'posix_getgrgid' => 1,
                      'cpdf_import_jpeg' => 1,
                      'pdf_setrgbcolor_stroke' => 1,
                      'strnatcmp' => 1,
                      'strrchr' => 1,
                      'pdf_set_horiz_scaling' => 1,
                      'mysql_field_seek' => 1,
                      'gzrewind' => 1,
                      'wddx_serialize_value' => 1,
                      'imagecolorclosest' => 1,
                      'posix_getsid' => 1,
                      'odbc_fetch_into' => 1,
                      'ftp_put' => 1,
                      'msql_drop_db' => 1,
                      'parse_str' => 1,
                      'filepro_fieldtype' => 1,
                      'array_merge_recursive' => 1,
                      'imap_binary' => 1,
                      'imap_base64' => 1,
                      'ldap_read' => 1,
                      'yp_master' => 1,
                      'getdate' => 1,
                      'pg_end_copy' => 1,
                      'mcrypt_module_get_algo_block_size' => 1,
                      'gregoriantojd' => 1,
                      'hw_docbyanchor' => 1,
                      'pg_fetch_row' => 1,
                      'ifx_pconnect' => 1,
                      'mysql_drop_db' => 1,
                      'gmp_and' => 1,
                      'msql' => 1,
                      'dl' => 1,
                      'msql_fetch_row' => 1,
                      'fdf_set_value' => 1,
                      'bcmod' => 1,
                      'mcal_event_set_description' => 1,
                      'imagefilledpolygon' => 1,
                      'sem_get' => 1,
                      'socket_set_timeout' => 1,
                      'crypt' => 1,
                      'ifx_errormsg' => 1,
                      'bindec' => 1,
                      'ifx_nullformat' => 1,
                      'mssql_field_length' => 1,
                      'mcal_open' => 1,
                      'mysql_result' => 1,
                      'sybase_result' => 1,
                      'cpdf_set_font' => 1,
                      'ldap_explode_dn' => 1,
                      'min' => 1,
                      'ifx_textasvarchar' => 1,
                      'pdf_execute_image' => 1,
                      'decoct' => 1,
                      'gmp_mod' => 1,
                      'basename' => 1,
                      'ldap_next_entry' => 1,
                      'imagestringup' => 1,
                      'jdtofrench' => 1,
                      'cpdf_translate' => 1,
                      'is_long' => 1,
                      'mysql_field_type' => 1,
                      'posix_getgrnam' => 1,
                      'sqrt' => 1,
                      'natsort' => 1,
                      'strnatcasecmp' => 1,
                      'hw_getchilddoccoll' => 1,
                      'msql_num_fields' => 1,
                      'user_error' => 1,
                      'openssl_verify' => 1,
                      'xslt_error' => 1,
                      'gmp_prob_prime' => 1,
                      'imagecolorallocate' => 1,
                      'ocinewdescriptor' => 1,
                      'openssl_sign' => 1,
                      'ftp_rawlist' => 1,
                      'count' => 1,
                      'each' => 1,
                      'shmop_write' => 1,
                      'class_exists' => 1,
                      'mssql_field_type' => 1,
                      'swf_startdoaction' => 1,
                      'cpdf_setlinejoin' => 1,
                      'escapeshellcmd' => 1,
                      'mcrypt_module_is_block_mode' => 1,
                      'gethostbynamel' => 1,
                      'flock' => 1,
                      'jdtojulian' => 1,
                      'dba_delete' => 1,
                      'ibase_trans' => 1,
                      'pdf_place_image' => 1,
                      'sybase_get_last_message' => 1,
                      'quotemeta' => 1,
                      'debugger_off' => 1,
                      'imagepsextendfont' => 1,
                      'chunk_split' => 1,
                      'mysql_field_name' => 1,
                      'ingres_pconnect' => 1,
                      'base64_decode' => 1,
                      'msql_numrows' => 1,
                      'imagecharup' => 1,
                      'swf_startshape' => 1,
                      'mysql_fetch_array' => 1,
                      'array_shift' => 1,
                      'easter_date' => 1,
                      'hw_root' => 1,
                      'rtrim' => 1,
                      'mysql_change_user' => 1,
                      'gmp_fact' => 1,
                      'pfpro_init' => 1,
                      'ingres_field_precision' => 1,
                      'cpdf_newpath' => 1,
                      'dirname' => 1,
                      'set_file_buffer' => 1,
                      'filepro_fieldwidth' => 1,
                      'pspell_config_mode' => 1,
                      'preg_quote' => 1,
                      'ob_get_length' => 1,
                      'chdir' => 1,
                      'opendir' => 1,
                      'swf_textwidth' => 1,
                      'imap_close' => 1,
                      'ocinewcursor' => 1,
                      'dbmnextkey' => 1,
                      'fdf_set_javascript_action' => 1,
                      'juliantojd' => 1,
                      'cpdf_set_text_matrix' => 1,
                      'shmop_close' => 1,
                      'eregi_replace' => 1,
                      'ovrimos_connect' => 1,
                      'cpdf_begin_text' => 1,
                      'ibase_free_result' => 1,
                      'ldap_add' => 1,
                      'cpdf_rotate' => 1,
                      'get_current_user' => 1,
                      'hw_pipedocument' => 1,
                      'define_syslog_variables' => 1,
                      'pspell_config_repl' => 1,
                      'readgzfile' => 1,
                      'cpdf_rmoveto' => 1,
                      'ora_error' => 1,
                      'yaz_errno' => 1,
                      'fdf_set_flags' => 1,
                      'hexdec' => 1,
                      'sin' => 1,
                      'metaphone' => 1,
                      'odbc_procedurecolumns' => 1,
                      'cpdf_set_subject' => 1,
                      'ora_columnname' => 1,
                      'ob_implicit_flush' => 1,
                      'gmp_cmp' => 1,
                      'ldap_mod_del' => 1,
                      'imagecolorat' => 1,
                      'cybercash_base64_decode' => 1,
                      'feof' => 1,
                      'close' => 1,
                      'func_get_args' => 1,
                      'array_keys' => 1,
                      'ibase_rollback' => 1,
                      'base64_encode' => 1,
                      'gmp_add' => 1,
                      'mcal_store_event' => 1,
                      'get_loaded_extensions' => 1,
                      'swf_shapefilloff' => 1,
                      'odbc_result' => 1,
                      'pg_fieldnum' => 1,
                      'uasort' => 1,
                      'swf_removeobject' => 1,
                      'imap_renamemailbox' => 1,
                      'yaz_wait' => 1,
                      'chmod' => 1,
                      'acos' => 1,
                      'mssql_min_error_severity' => 1,
                      'swf_actiongotoframe' => 1,
                      'ora_logoff' => 1,
                      'ldap_search' => 1,
                      'openssl_seal' => 1,
                      'rewinddir' => 1,
                      'pdf_set_leading' => 1,
                      'mhash' => 1,
                      'mcal_event_set_end' => 1,
                      'mysql_field_table' => 1,
                      'fdf_create' => 1,
                      'msql_error' => 1,
                      'odbc_prepare' => 1,
                      'listen' => 1,
                      'ltrim' => 1,
                      'swf_fontslant' => 1,
                      'pspell_config_runtogether' => 1,
                      'localtime' => 1,
                      'get_meta_tags' => 1,
                      'ocilogon' => 1,
                      'array_count_values' => 1,
                      'cpdf_set_word_spacing' => 1,
                      'hw_unlock' => 1,
                      'odbc_close_all' => 1,
                      'array_splice' => 1,
                      'hw_cp' => 1,
                      'sesam_execimm' => 1,
                      'ldap_first_entry' => 1,
                      'flush' => 1,
                      'dbase_numfields' => 1,
                      'odbc_field_scale' => 1,
                      'ora_bind' => 1,
                      'pg_untrace' => 1,
                      'pg_loreadall' => 1,
                      'imagettftext' => 1,
                      'phpcredits' => 1,
                      'pspell_check' => 1,
                      'range' => 1,
                      'mysql_data_seek' => 1,
                      'array' => 1,
                      'imap_clearflag_full' => 1,
                      'ldap_connect' => 1,
                      'parse_url' => 1,
                      'ovrimos_commit' => 1,
                      'pspell_new_personal' => 1,
                      'imap_header' => 1,
                      'connection_timeout' => 1,
                      'odbc_columnprivileges' => 1,
                      'realpath' => 1,
                      'cpdf_page_init' => 1,
                      'dbmreplace' => 1,
                      'cpdf_set_title' => 1,
                      'pdf_rotate' => 1,
                      'ifx_copy_blob' => 1,
                      'define' => 1,
                      'fileowner' => 1,
                      'xml_parser_create' => 1,
                      'mcrypt_create_iv' => 1,
                      'pdf_set_border_dash' => 1,
                      'ingres_field_type' => 1,
                      'aspell_new' => 1,
                      'show_source' => 1,
                      'bindtextdomain' => 1,
                      'gmp_divexact' => 1,
                      'array_push' => 1,
                      'imagecolorresolve' => 1,
                      'imagepsencodefont' => 1,
                      'array_intersect' => 1,
                      'mcrypt_generic' => 1,
                      'cpdf_set_text_pos' => 1,
                      'mcal_event_set_recur_monthly_mday' => 1,
                      'pg_fieldsize' => 1,
                      'pspell_new' => 1,
                      'sybase_affected_rows' => 1,
                      'jdmonthname' => 1,
                      'swf_scale' => 1,
                      'preg_match' => 1,
                      'getcwd' => 1,
                      'ifx_byteasvarchar' => 1,
                      'sybase_field_seek' => 1,
                      'sesam_free_result' => 1,
                      'pspell_config_save_repl' => 1,
                      'pfpro_version' => 1,
                      'fseek' => 1,
                      'ora_plogon' => 1,
                      'swf_placeobject' => 1,
                      'ovrimos_fetch_into' => 1,
                      'md5' => 1,
                      'msql_fetch_field' => 1,
                      'odbc_tables' => 1,
                      'ifx_close' => 1,
                      'ora_commitoff' => 1,
                      'mcal_event_set_recur_yearly' => 1,
                      'imagecreatefromjpeg' => 1,
                      'ocierror' => 1,
                      'ovrimos_exec' => 1,
                      'ftp_mkdir' => 1,
                      'cos' => 1,
                      'pg_tty' => 1,
                      'sprintf' => 1,
                      'shmop_size' => 1,
                      'imap_unsubscribe' => 1,
                      'odbc_field_precision' => 1,
                      'swf_actionprevframe' => 1,
                      'session_register' => 1,
                      'pdf_rect' => 1,
                      'rand' => 1,
                      'snmp_get_quick_print' => 1,
                      'getmyinode' => 1,
                      'doubleval' => 1,
                      'odbc_field_name' => 1,
                      'swf_lookat' => 1,
                      'passthru' => 1,
                      'pspell_config_ignore' => 1,
                      'hw_getparentsobj' => 1,
                      'odbc_specialcolumns' => 1,
                      'mssql_fetch_array' => 1,
                      'imagefontwidth' => 1,
                      'cpdf_finalize_page' => 1,
                      'imagecolorexact' => 1,
                      'umask' => 1,
                      'mcrypt_module_is_block_algorithm' => 1,
                      'ocinlogon' => 1,
                      'swf_definepoly' => 1,
                      'posix_getuid' => 1,
                      'header' => 1
                    },
          'lineComment' => [
                             '//',
                             '#'
                           ],
          'delimiters' => ',(){}[]-+*%/="\'~!&|<>?:;.#@',
          'key1' => {
                      'm_pi' => 1,
                      'm_sqrt2' => 1,
                      'e_parse' => 1,
                      'string' => 1,
                      'if' => 1,
                      'double' => 1,
                      'm_log2e' => 1,
                      'm_ln10' => 1,
                      'extends' => 1,
                      'break' => 1,
                      'bool' => 1,
                      'm_pi_4' => 1,
                      'endforeach' => 1,
                      'm_lnpi' => 1,
                      'm_e' => 1,
                      'm_2_sqrtpi' => 1,
                      'm_pi_2' => 1,
                      'e_error' => 1,
                      '$' => 1,
                      'function' => 1,
                      'int' => 1,
                      'do' => 1,
                      'true' => 1,
                      'void' => 1,
                      'case' => 1,
                      'array' => 1,
                      'float' => 1,
                      'var' => 1,
                      'real' => 1,
                      'm_ln2' => 1,
                      'endfor' => 1,
                      'm_sqrt1_2' => 1,
                      'm_1_pi' => 1,
                      '__file__' => 1,
                      'endwhile' => 1,
                      'e_warning' => 1,
                      'switch' => 1,
                      'char' => 1,
                      'mixed' => 1,
                      'endswitch' => 1,
                      'require' => 1,
                      'false' => 1,
                      'static' => 1,
                      'php' => 1,
                      'integer' => 1,
                      'm_sqrtpi' => 1,
                      'new' => 1,
                      'php_version' => 1,
                      'endif' => 1,
                      'e_notice' => 1,
                      'for' => 1,
                      'else' => 1,
                      'default' => 1,
                      '__line__' => 1,
                      'm_euler' => 1,
                      'm_2_pi' => 1,
                      'class' => 1,
                      'continue' => 1,
                      'object' => 1,
                      'include' => 1,
                      'foreach' => 1,
                      'm_log10e' => 1,
                      'php_os' => 1,
                      'long' => 1,
                      '@' => 1,
                      'm_sqrt3' => 1,
                      'elseif' => 1,
                      'global' => 1,
                      'return' => 1,
                      'old_function' => 1,
                      'while' => 1
                    },
          'quot' => [
                      '\'',
                      '"'
                    ],
          'blockCommentOff' => [
                                 '*/'
                               ],
          'escape' => '\\',
          'continueQuote' => 0
        };

}

1;
__END__
