package Text::Highlight::Java;
use strict;

sub syntax
{
	return {
          'name' => 'Java',
          'blockCommentOn' => [
                                '/*'
                              ],
          'case' => 1,
          'key2' => {
                      'ObjectOutputStream' => 1,
                      'ChoiceFormat' => 1,
                      'CheckboxGroup' => 1,
                      'DynamicImplementation' => 1,
                      'DefaultCaret' => 1,
                      'MetalCheckBoxIcon' => 1,
                      'ControllerEventListener' => 1,
                      'JLayeredPane' => 1,
                      'MetaEventListener' => 1,
                      'Provider' => 1,
                      'IDLEntity' => 1,
                      'Map.Entry' => 1,
                      'SequenceInputStream' => 1,
                      'ReferenceQueue' => 1,
                      'FormatConversionProvider' => 1,
                      'RMIClientSocketFactory' => 1,
                      'DefaultTableColumnModel' => 1,
                      'Invalid' => 1,
                      'WCharSeqHelper' => 1,
                      'JButton' => 1,
                      'OpenType' => 1,
                      'ContextualRenderedImageFactory' => 1,
                      'KeyFactorySpi' => 1,
                      'AlgorithmParameters' => 1,
                      'RuntimeException' => 1,
                      'HTMLFrameHyperlinkEvent' => 1,
                      'SoftBevelBorder' => 1,
                      'DynArray' => 1,
                      'AudioPermission' => 1,
                      'DefinitionKind' => 1,
                      'ShortSeqHelper' => 1,
                      'WeakReference' => 1,
                      'ButtonModel' => 1,
                      'StyledEditorKit.ItalicAction' => 1,
                      'ULongLongSeqHolder' => 1,
                      'UnexpectedException' => 1,
                      'MetalIconFactory.TreeFolderIcon' => 1,
                      'InvalidKeyException' => 1,
                      'Certificate.CertificateRep' => 1,
                      'NameValuePair' => 1,
                      'PrintWriter' => 1,
                      'NamingManager' => 1,
                      'DefaultSingleSelectionModel' => 1,
                      'BooleanControl.Type' => 1,
                      'ICC_ColorSpace' => 1,
                      'DefaultMenuLayout' => 1,
                      'MultiLabelUI' => 1,
                      'DirectoryManager' => 1,
                      'UIDefaults.LazyInputMap' => 1,
                      'SimpleAttributeSet' => 1,
                      'AttributedCharacterIterator.Attribute' => 1,
                      'ShortMessage' => 1,
                      'Highlighter.Highlight' => 1,
                      'DTDConstants' => 1,
                      'LinkException' => 1,
                      'CharHolder' => 1,
                      'ObjectInputStream.GetField' => 1,
                      'FontFormatException' => 1,
                      'UndoableEditSupport' => 1,
                      'StringIndexOutOfBoundsException' => 1,
                      'MetalSeparatorUI' => 1,
                      'FloatSeqHolder' => 1,
                      'Element' => 1,
                      'DefaultCellEditor' => 1,
                      'ObjectHelper' => 1,
                      'InputMap' => 1,
                      'JarFile' => 1,
                      'InvalidParameterSpecException' => 1,
                      'ZipFile' => 1,
                      'PageAttributes.PrintQualityType' => 1,
                      'ContentModel' => 1,
                      'ActivationSystem' => 1,
                      'AlgorithmParameterGenerator' => 1,
                      'UShortSeqHelper' => 1,
                      'JEditorPane' => 1,
                      'ClassCircularityError' => 1,
                      'TRANSACTION_ROLLEDBACK' => 1,
                      'FormView' => 1,
                      'Compiler' => 1,
                      'File' => 1,
                      'DocumentListener' => 1,
                      'URL' => 1,
                      'UnknownObjectException' => 1,
                      'Mixer.Info' => 1,
                      'DoubleSeqHelper' => 1,
                      'InvalidAttributeValueException' => 1,
                      'AbstractLayoutCache' => 1,
                      'MouseEvent' => 1,
                      'ImagingOpException' => 1,
                      'MenuElement' => 1,
                      'Component' => 1,
                      'CertificateExpiredException' => 1,
                      'SimpleDateFormat' => 1,
                      'Patch' => 1,
                      'ApplicationException' => 1,
                      'MidiFileWriter' => 1,
                      'ServiceDetail' => 1,
                      'NullPointerException' => 1,
                      'StyledEditorKit.ForegroundAction' => 1,
                      'ContextList' => 1,
                      'BasicTextUI.BasicCaret' => 1,
                      'SecureRandom' => 1,
                      'RasterFormatException' => 1,
                      'LinkageError' => 1,
                      'Control.Type' => 1,
                      'NumberFormat' => 1,
                      'FlowLayout' => 1,
                      'BlockView' => 1,
                      'DynStruct' => 1,
                      'CollationElementIterator' => 1,
                      'Ref' => 1,
                      'MetalBorders.RolloverButtonBorder' => 1,
                      'ObjectOutput' => 1,
                      'BindingListHolder' => 1,
                      'MessageFormat' => 1,
                      'MetalFileChooserUI' => 1,
                      'PrinterJob' => 1,
                      'PrinterAbortException' => 1,
                      'SocketSecurityException' => 1,
                      'Attributes.Name' => 1,
                      'HTML' => 1,
                      'GridLayout' => 1,
                      'INITIALIZE' => 1,
                      'TextAction' => 1,
                      'NoClassDefFoundError' => 1,
                      'StateEditable' => 1,
                      'X509CRLEntry' => 1,
                      'Serializable' => 1,
                      'RemoteException' => 1,
                      'LookupOp' => 1,
                      'LongLongSeqHolder' => 1,
                      'EnumControl.Type' => 1,
                      'BeanContextServiceProviderBeanInfo' => 1,
                      'MidiEvent' => 1,
                      'AbstractAction' => 1,
                      'Comparator' => 1,
                      'HasControls' => 1,
                      'TextLayout' => 1,
                      'ListCellRenderer' => 1,
                      'IndirectionException' => 1,
                      'HTMLEditorKit.InsertHTMLTextAction' => 1,
                      'Applet' => 1,
                      'Number' => 1,
                      'MetalRadioButtonUI' => 1,
                      'MetalToolTipUI' => 1,
                      'Window' => 1,
                      'GridBagLayout' => 1,
                      'Keymap' => 1,
                      'IMP_LIMIT' => 1,
                      'MenuBarUI' => 1,
                      'HTMLEditorKit' => 1,
                      'Document' => 1,
                      'ContainerAdapter' => 1,
                      'BasicComboBoxRenderer' => 1,
                      '_NamingContextImplBase' => 1,
                      'Error' => 1,
                      'BAD_OPERATION' => 1,
                      'ContentHandler' => 1,
                      'ValueBaseHolder' => 1,
                      'TileObserver' => 1,
                      'JMenuItem' => 1,
                      'ActivationInstantiator' => 1,
                      'JobAttributes' => 1,
                      'BasicTextUI.BasicHighlighter' => 1,
                      'PUBLIC_MEMBER' => 1,
                      'PageAttributes.OrientationRequestedType' => 1,
                      'PaintContext' => 1,
                      'SocketPermission' => 1,
                      'Authenticator' => 1,
                      'AbstractDocument.Content' => 1,
                      'PageFormat' => 1,
                      'MouseMotionAdapter' => 1,
                      'LineEvent' => 1,
                      'BeanContextServicesSupport.BCSSServiceProvider' => 1,
                      'IllegalComponentStateException' => 1,
                      'MetalProgressBarUI' => 1,
                      'GradientPaint' => 1,
                      'BasicTextFieldUI' => 1,
                      'COMM_FAILURE' => 1,
                      'DataBufferShort' => 1,
                      'JToggleButton.ToggleButtonModel' => 1,
                      'Environment' => 1,
                      'ServerNotActiveException' => 1,
                      'IRObjectOperations' => 1,
                      'ListSelectionEvent' => 1,
                      'EventContext' => 1,
                      'BeanContextServiceRevokedEvent' => 1,
                      'DefaultEditorKit.CutAction' => 1,
                      'MetalComboBoxButton' => 1,
                      'InvalidValue' => 1,
                      'AccessibleStateSet' => 1,
                      'AbstractBorder' => 1,
                      'VariableHeightLayoutCache' => 1,
                      'OverlayLayout' => 1,
                      'MetalIconFactory.FileIcon16' => 1,
                      'BindingTypeHelper' => 1,
                      'TableView' => 1,
                      'ElementIterator' => 1,
                      'Clip' => 1,
                      'BadLocationException' => 1,
                      'MenuItem' => 1,
                      'WrappedPlainView' => 1,
                      'AbstractButton' => 1,
                      'TypeCode' => 1,
                      'NameHolder' => 1,
                      'ExpandVetoException' => 1,
                      'EnumControl' => 1,
                      'ByteArrayInputStream' => 1,
                      'INTERNAL' => 1,
                      'RemoteRef' => 1,
                      'DefaultColorSelectionModel' => 1,
                      'CompositeContext' => 1,
                      'Byte' => 1,
                      'OutOfMemoryError' => 1,
                      'Naming' => 1,
                      'BasicInternalFrameUI' => 1,
                      'CollationKey' => 1,
                      'ColorChooserUI' => 1,
                      'ServerException' => 1,
                      'ReplicateScaleFilter' => 1,
                      'RSAPrivateKeySpec' => 1,
                      'PrintStream' => 1,
                      'PixelGrabber' => 1,
                      'SQLData' => 1,
                      'FloatControl' => 1,
                      'UIDefaults.LazyValue' => 1,
                      'FontUIResource' => 1,
                      'BasicPermission' => 1,
                      'MethodDescriptor' => 1,
                      'Polygon' => 1,
                      'MetalTabbedPaneUI' => 1,
                      'ServerRequest' => 1,
                      'DynSequence' => 1,
                      'MultiPixelPackedSampleModel' => 1,
                      'KeySpec' => 1,
                      'UNSUPPORTED_POLICY_VALUE' => 1,
                      'Adler32' => 1,
                      'BasicButtonUI' => 1,
                      'NoSuchAttributeException' => 1,
                      'ObjectInputValidation' => 1,
                      'ChangeListener' => 1,
                      'JOptionPane' => 1,
                      'RunTimeOperations' => 1,
                      'TabableView' => 1,
                      'DataLine' => 1,
                      'ColorChooserComponentFactory' => 1,
                      'Security' => 1,
                      'ICC_ProfileRGB' => 1,
                      'Character.UnicodeBlock' => 1,
                      'SoundbankResource' => 1,
                      'CharSeqHolder' => 1,
                      'BasicMenuBarUI' => 1,
                      'Throwable' => 1,
                      'ObjectStreamConstants' => 1,
                      'MetalCheckBoxUI' => 1,
                      'MenuItemUI' => 1,
                      'IDLTypeHelper' => 1,
                      'DoubleSeqHolder' => 1,
                      'SQLException' => 1,
                      'DirStateFactory.Result' => 1,
                      'ULongSeqHolder' => 1,
                      'Collection' => 1,
                      'BasicDesktopIconUI' => 1,
                      'BeanContext' => 1,
                      'Point' => 1,
                      'DragSourceEvent' => 1,
                      'AncestorListener' => 1,
                      'Random' => 1,
                      'PropertyEditorSupport' => 1,
                      'DynAny' => 1,
                      'Printable' => 1,
                      'ImageObserver' => 1,
                      'CompoundBorder' => 1,
                      'Repository' => 1,
                      'LinkRef' => 1,
                      'CompositeName' => 1,
                      'BorderUIResource.MatteBorderUIResource' => 1,
                      'AlgorithmParameterGeneratorSpi' => 1,
                      'Request' => 1,
                      'NotEmpty' => 1,
                      'JPanel' => 1,
                      'BooleanHolder' => 1,
                      'InputSubset' => 1,
                      'ShapeGraphicAttribute' => 1,
                      'BasicListUI' => 1,
                      'ReferralException' => 1,
                      'NotOwnerException' => 1,
                      'ViewportUI' => 1,
                      'LabelUI' => 1,
                      'DeflaterOutputStream' => 1,
                      'AWTError' => 1,
                      'SearchResult' => 1,
                      'MetalIconFactory.PaletteCloseIcon' => 1,
                      'INV_OBJREF' => 1,
                      'ContainerListener' => 1,
                      'AccessibleRelationSet' => 1,
                      'InputStream' => 1,
                      'FieldPosition' => 1,
                      'DebugGraphics' => 1,
                      'X509CRL' => 1,
                      'BasicBorders.FieldBorder' => 1,
                      'RMISecurityException' => 1,
                      'JComboBox' => 1,
                      'GraphicsDevice' => 1,
                      'GraphicsEnvironment' => 1,
                      'BasicRadioButtonUI' => 1,
                      'GrayFilter' => 1,
                      'NamingContext' => 1,
                      'AnySeqHelper' => 1,
                      'HashMap' => 1,
                      'InvalidObjectException' => 1,
                      'RGBImageFilter' => 1,
                      'JToggleButton' => 1,
                      'ColorSpace' => 1,
                      'MetalBorders.ToggleButtonBorder' => 1,
                      'TextField' => 1,
                      'ServantObject' => 1,
                      'InitialDirContext' => 1,
                      'RemarshalException' => 1,
                      'StyleSheet.BoxPainter' => 1,
                      'Object' => 1,
                      'InternalFrameAdapter' => 1,
                      'PropertyEditorManager' => 1,
                      'MenuComponent' => 1,
                      'IllegalPathStateException' => 1,
                      'MultiProgressBarUI' => 1,
                      'DragSourceDropEvent' => 1,
                      'Port' => 1,
                      'InvalidMidiDataException' => 1,
                      'HTMLDocument' => 1,
                      'TreePath' => 1,
                      'Highlighter.HighlightPainter' => 1,
                      '_Remote_Stub' => 1,
                      'Modifier' => 1,
                      'MetalButtonUI' => 1,
                      'DataBuffer' => 1,
                      'UNKNOWN' => 1,
                      'CannotUndoException' => 1,
                      'BufferedImage' => 1,
                      'SliderUI' => 1,
                      'UnsatisfiedLinkError' => 1,
                      'TargetDataLine' => 1,
                      'Transferable' => 1,
                      'NamingContextHolder' => 1,
                      'ValueHandler' => 1,
                      'PanelUI' => 1,
                      'View' => 1,
                      'MultiLookAndFeel' => 1,
                      'MidiUnavailableException' => 1,
                      'IRObject' => 1,
                      'URLClassLoader' => 1,
                      'HierarchyEvent' => 1,
                      'DefaultTreeCellEditor' => 1,
                      'DataInput' => 1,
                      'DefaultTableCellRenderer' => 1,
                      'BasicSplitPaneDivider' => 1,
                      'CannotProceed' => 1,
                      'ViewportLayout' => 1,
                      'TextMeasurer' => 1,
                      'Position' => 1,
                      'MetalIconFactory' => 1,
                      'MixerProvider' => 1,
                      'Method' => 1,
                      'RenderedImageFactory' => 1,
                      'Reference' => 1,
                      'GuardedObject' => 1,
                      'KeyStroke' => 1,
                      'InvalidSearchControlsException' => 1,
                      'EmptyBorder' => 1,
                      'CaretListener' => 1,
                      'InvokeHandler' => 1,
                      'ParameterDescriptor' => 1,
                      'Dictionary' => 1,
                      'RMISocketFactory' => 1,
                      'PageAttributes' => 1,
                      'Rectangle2D' => 1,
                      'Ellipse2D.Float' => 1,
                      'JLabel' => 1,
                      'DragGestureEvent' => 1,
                      'Util' => 1,
                      'ThreadLocal' => 1,
                      'SocketImpl' => 1,
                      'ObjectInput' => 1,
                      'BindingIteratorHelper' => 1,
                      'ProfileDataException' => 1,
                      'NotFound' => 1,
                      'DatagramPacket' => 1,
                      'IDLTypeOperations' => 1,
                      'DefaultListSelectionModel' => 1,
                      'UnknownError' => 1,
                      'JToolTip' => 1,
                      'MatteBorder' => 1,
                      'PolicyListHolder' => 1,
                      'ZipOutputStream' => 1,
                      'PartialResultException' => 1,
                      'PhantomReference' => 1,
                      'FileReader' => 1,
                      'MultiSeparatorUI' => 1,
                      'AffineTransform' => 1,
                      'RemoteObject' => 1,
                      'DTD' => 1,
                      'DSAParameterSpec' => 1,
                      'DefaultEditorKit.BeepAction' => 1,
                      'TreeSelectionListener' => 1,
                      'PopupMenu' => 1,
                      'ImageFilter' => 1,
                      'String' => 1,
                      'JMenuBar' => 1,
                      'CodeSource' => 1,
                      'AccessControlContext' => 1,
                      'WindowAdapter' => 1,
                      'ScrollPaneLayout' => 1,
                      'NamingContextHelper' => 1,
                      'Hashtable' => 1,
                      'StructMember' => 1,
                      'DropTargetContext' => 1,
                      'MetalBorders.MenuItemBorder' => 1,
                      'DataBufferInt' => 1,
                      'Cursor' => 1,
                      'CheckedInputStream' => 1,
                      'StringSelection' => 1,
                      'BasicEditorPaneUI' => 1,
                      'VersionSpecHelper' => 1,
                      'RenderingHints' => 1,
                      'StringValueHelper' => 1,
                      'AccessException' => 1,
                      'JTextComponent' => 1,
                      'RSAPrivateKey' => 1,
                      'Inflater' => 1,
                      'Character.Subset' => 1,
                      'ListResourceBundle' => 1,
                      'StringCharacterIterator' => 1,
                      'FilePermission' => 1,
                      'VM_NONE' => 1,
                      'BeanContextEvent' => 1,
                      'ObjectView' => 1,
                      'RMIServerSocketFactory' => 1,
                      'BeanContextServiceRevokedListener' => 1,
                      'PublicKey' => 1,
                      'DataOutputStream' => 1,
                      'BatchUpdateException' => 1,
                      'DragSourceDragEvent' => 1,
                      'InternalFrameUI' => 1,
                      'DynUnion' => 1,
                      'SinglePixelPackedSampleModel' => 1,
                      'CurrentOperations' => 1,
                      'SocketException' => 1,
                      'PropertyChangeEvent' => 1,
                      'AttributedCharacterIterator' => 1,
                      'KeyStoreException' => 1,
                      '_BindingIteratorStub' => 1,
                      'ValueBaseHelper' => 1,
                      'DefaultStyledDocument.ElementSpec' => 1,
                      'UnsolicitedNotificationListener' => 1,
                      'TreeSelectionModel' => 1,
                      'StringTokenizer' => 1,
                      'BigDecimal' => 1,
                      'ScrollPaneUI' => 1,
                      'Position.Bias' => 1,
                      'URLStreamHandler' => 1,
                      'HierarchyBoundsAdapter' => 1,
                      'FilterReader' => 1,
                      'FixedHolder' => 1,
                      'BeanContextMembershipEvent' => 1,
                      'StreamCorruptedException' => 1,
                      'MetalBorders' => 1,
                      'SchemaViolationException' => 1,
                      'EOFException' => 1,
                      'AbstractUndoableEdit' => 1,
                      'IllegalStateException' => 1,
                      'LineBreakMeasurer' => 1,
                      'JSlider' => 1,
                      'TreeModelListener' => 1,
                      'NamingEnumeration' => 1,
                      'MetalDesktopIconUI' => 1,
                      'AccessibleHypertext' => 1,
                      'Transmitter' => 1,
                      'AccessibleAction' => 1,
                      'CompoundControl.Type' => 1,
                      'NameComponentHolder' => 1,
                      'SortedMap' => 1,
                      'Scrollbar' => 1,
                      'Paper' => 1,
                      'LastOwnerException' => 1,
                      'TCKind' => 1,
                      'MultiPanelUI' => 1,
                      'MetalIconFactory.FolderIcon16' => 1,
                      'Rectangle' => 1,
                      'NotFoundReasonHolder' => 1,
                      'Externalizable' => 1,
                      'AttributeModificationException' => 1,
                      'Field' => 1,
                      'ConcurrentModificationException' => 1,
                      'SQLPermission' => 1,
                      'AbstractDocument.ElementEdit' => 1,
                      'BeanContextServiceProvider' => 1,
                      'CurrentHelper' => 1,
                      'JTextComponent.KeyBinding' => 1,
                      'JList' => 1,
                      'LongHolder' => 1,
                      'ClassDesc' => 1,
                      'InterruptedNamingException' => 1,
                      'UIResource' => 1,
                      'InetAddress' => 1,
                      'IllegalThreadStateException' => 1,
                      'IllegalAccessException' => 1,
                      'BindingListHelper' => 1,
                      'PropertyPermission' => 1,
                      'FileDialog' => 1,
                      'JobAttributes.SidesType' => 1,
                      'FileWriter' => 1,
                      'UnionMember' => 1,
                      'OBJECT_NOT_EXIST' => 1,
                      'DecimalFormatSymbols' => 1,
                      'ShortSeqHolder' => 1,
                      'NameValuePairHelper' => 1,
                      'AudioFileReader' => 1,
                      'IOException' => 1,
                      'NoSuchAlgorithmException' => 1,
                      'BeanContextSupport.BCSIterator' => 1,
                      'PortableRemoteObjectDelegate' => 1,
                      'Beans' => 1,
                      'VM_TRUNCATABLE' => 1,
                      'VM_ABSTRACT' => 1,
                      'GeneralSecurityException' => 1,
                      'Graphics' => 1,
                      'BasicBorders.MarginBorder' => 1,
                      'ServerSocket' => 1,
                      'JTextPane' => 1,
                      'JRadioButtonMenuItem' => 1,
                      'DefaultDesktopManager' => 1,
                      'RenderableImageProducer' => 1,
                      'NO_RESPONSE' => 1,
                      'MetalBorders.TextFieldBorder' => 1,
                      'Exception' => 1,
                      'InvocationHandler' => 1,
                      'TableCellEditor' => 1,
                      'Package' => 1,
                      'BasicPopupMenuUI' => 1,
                      'Short' => 1,
                      'BasicBorders.MenuBarBorder' => 1,
                      'TableColumnModel' => 1,
                      'RenderingHints.Key' => 1,
                      'BasicMenuItemUI' => 1,
                      'BeanContextProxy' => 1,
                      'JScrollBar' => 1,
                      'Ellipse2D.Double' => 1,
                      'CustomValue' => 1,
                      'StreamTokenizer' => 1,
                      'Iterator' => 1,
                      'JTree' => 1,
                      'JobAttributes.DefaultSelectionType' => 1,
                      'StringWriter' => 1,
                      'Menu' => 1,
                      'System' => 1,
                      'InvalidAttributesException' => 1,
                      'UnmarshalException' => 1,
                      'JarURLConnection' => 1,
                      'AWTEvent' => 1,
                      'TRANSACTION_REQUIRED' => 1,
                      'SecurityManager' => 1,
                      'OutputStreamWriter' => 1,
                      'AbstractListModel' => 1,
                      'Sequencer' => 1,
                      'Port.Info' => 1,
                      'MetalIconFactory.TreeControlIcon' => 1,
                      'FileDescriptor' => 1,
                      'SingleSelectionModel' => 1,
                      'RoundRectangle2D.Float' => 1,
                      'RegistryHandler' => 1,
                      'ParsePosition' => 1,
                      'CTX_RESTRICT_SCOPE' => 1,
                      'CheckboxMenuItem' => 1,
                      'ComboBoxEditor' => 1,
                      'StackOverflowError' => 1,
                      'MenuContainer' => 1,
                      'InvalidClassException' => 1,
                      'Toolkit' => 1,
                      'AccessibleIcon' => 1,
                      'Box' => 1,
                      'Clipboard' => 1,
                      'BasicProgressBarUI' => 1,
                      'CropImageFilter' => 1,
                      'Unreferenced' => 1,
                      'PKCS8EncodedKeySpec' => 1,
                      'BasicGraphicsUtils' => 1,
                      'DatagramSocket' => 1,
                      'DocumentEvent.EventType' => 1,
                      'Segment' => 1,
                      'RSAPublicKeySpec' => 1,
                      'BeanContextChildSupport' => 1,
                      'NotFoundReason' => 1,
                      'MetalInternalFrameUI' => 1,
                      'BandedSampleModel' => 1,
                      'MetalBorders.TableHeaderBorder' => 1,
                      'ContentHandlerFactory' => 1,
                      'TableHeaderUI' => 1,
                      'NoSuchProviderException' => 1,
                      'KeyPair' => 1,
                      'IndexedPropertyDescriptor' => 1,
                      'ComponentListener' => 1,
                      'MultiMenuBarUI' => 1,
                      'BindingTypeHolder' => 1,
                      'IconView' => 1,
                      'PrinterGraphics' => 1,
                      'MenuDragMouseListener' => 1,
                      'DirStateFactory' => 1,
                      'BufferedWriter' => 1,
                      'PolicyOperations' => 1,
                      'Font' => 1,
                      'ClassCastException' => 1,
                      'ContextNotEmptyException' => 1,
                      'KeyPairGenerator' => 1,
                      'PasswordView' => 1,
                      'NoSuchFieldException' => 1,
                      'OctetSeqHelper' => 1,
                      'TextLayout.CaretPolicy' => 1,
                      'WindowListener' => 1,
                      'Stroke' => 1,
                      'Resolver' => 1,
                      'NamingListener' => 1,
                      'HierarchyListener' => 1,
                      'ActiveEvent' => 1,
                      'RowMapper' => 1,
                      'ActivationException' => 1,
                      'AccessibleState' => 1,
                      'LineUnavailableException' => 1,
                      'Tie' => 1,
                      'MutableAttributeSet' => 1,
                      'PopupMenuUI' => 1,
                      'ItemEvent' => 1,
                      'FontRenderContext' => 1,
                      'ClassNotFoundException' => 1,
                      'ComponentInputMapUIResource' => 1,
                      'Signature' => 1,
                      'ParseException' => 1,
                      'NotEmptyHolder' => 1,
                      'InsufficientResourcesException' => 1,
                      'ImageGraphicAttribute' => 1,
                      'GraphicAttribute' => 1,
                      'CubicCurve2D.Float' => 1,
                      'UnsolicitedNotification' => 1,
                      'DSAPrivateKeySpec' => 1,
                      'JPopupMenu.Separator' => 1,
                      'INTF_REPOS' => 1,
                      'EventListenerList' => 1,
                      'RefAddr' => 1,
                      'Principal' => 1,
                      'DragGestureListener' => 1,
                      'BasicRootPaneUI' => 1,
                      'VoiceStatus' => 1,
                      'GridBagConstraints' => 1,
                      'AdjustmentEvent' => 1,
                      'AlreadyBoundException' => 1,
                      'ActivationID' => 1,
                      'ValueBase' => 1,
                      'InputContext' => 1,
                      'ByteLookupTable' => 1,
                      'Types' => 1,
                      'Name' => 1,
                      'MetalLookAndFeel' => 1,
                      'DSAKey' => 1,
                      'SecurityException' => 1,
                      'NameComponentHelper' => 1,
                      'ListSelectionListener' => 1,
                      'LongLongSeqHelper' => 1,
                      'JTree.DynamicUtilTreeNode' => 1,
                      'AlgorithmParameterSpec' => 1,
                      'Dialog' => 1,
                      'DataTruncation' => 1,
                      'AudioFormat' => 1,
                      'Collections' => 1,
                      'JFileChooser' => 1,
                      'Format' => 1,
                      'Ellipse2D' => 1,
                      'JobAttributes.MultipleDocumentHandlingType' => 1,
                      'MetalBorders.PopupMenuBorder' => 1,
                      'AlreadyBound' => 1,
                      'MultiComboBoxUI' => 1,
                      'AbstractCellEditor' => 1,
                      'AccessibleResourceBundle' => 1,
                      'PrivateKey' => 1,
                      'CaretEvent' => 1,
                      'NotContextException' => 1,
                      'Mixer' => 1,
                      'MulticastSocket' => 1,
                      'BorderUIResource.TitledBorderUIResource' => 1,
                      'Any' => 1,
                      'StubNotFoundException' => 1,
                      'DefaultButtonModel' => 1,
                      'MultiMenuItemUI' => 1,
                      'PolicyHelper' => 1,
                      'JToolBar.Separator' => 1,
                      'Skeleton' => 1,
                      'IDLType' => 1,
                      'MetalScrollButton' => 1,
                      'BasicLookAndFeel' => 1,
                      'ColorUIResource' => 1,
                      'ActionMap' => 1,
                      'AudioInputStream' => 1,
                      'Accessible' => 1,
                      'TableUI' => 1,
                      'DragSourceContext' => 1,
                      'ZipInputStream' => 1,
                      'MarshalException' => 1,
                      'VisibilityHelper' => 1,
                      'TextAttribute' => 1,
                      'Robot' => 1,
                      'FocusListener' => 1,
                      'BeanContextMembershipListener' => 1,
                      'ComponentColorModel' => 1,
                      'DatagramSocketImpl' => 1,
                      'ThreadGroup' => 1,
                      'Registry' => 1,
                      'PipedWriter' => 1,
                      'Current' => 1,
                      'IndexOutOfBoundsException' => 1,
                      'Box.Filler' => 1,
                      'MidiDeviceProvider' => 1,
                      'FileNotFoundException' => 1,
                      'AnyHolder' => 1,
                      'ActivationGroup' => 1,
                      'HTMLDocument.Iterator' => 1,
                      'BasicBorders.ButtonBorder' => 1,
                      'TypeCodeHolder' => 1,
                      'KeyPairGeneratorSpi' => 1,
                      'Sequencer.SyncMode' => 1,
                      'Clob' => 1,
                      'ScrollPane' => 1,
                      'JRootPane' => 1,
                      'OutputStream' => 1,
                      'Identity' => 1,
                      'InternalError' => 1,
                      'ConnectIOException' => 1,
                      'OptionalDataException' => 1,
                      'MouseListener' => 1,
                      'BindingIterator' => 1,
                      'ActivationGroupID' => 1,
                      'SecureRandomSpi' => 1,
                      'FilenameFilter' => 1,
                      'BasicComboPopup' => 1,
                      'LayeredHighlighter' => 1,
                      'GregorianCalendar' => 1,
                      'CellEditorListener' => 1,
                      'JDesktopPane' => 1,
                      'MenuKeyListener' => 1,
                      'MidiChannel' => 1,
                      'DigestException' => 1,
                      'MetalComboBoxIcon' => 1,
                      'PolicyError' => 1,
                      'DefaultTreeSelectionModel' => 1,
                      'SkeletonNotFoundException' => 1,
                      'ListIterator' => 1,
                      'SetOverrideTypeHelper' => 1,
                      'MultiViewportUI' => 1,
                      'MetalBorders.Flush3DBorder' => 1,
                      'BasicComboBoxRenderer.UIResource' => 1,
                      'TreeMap' => 1,
                      'RMIClassLoader' => 1,
                      'ComponentUI' => 1,
                      'RSAPrivateCrtKey' => 1,
                      'NameClassPair' => 1,
                      'TableCellRenderer' => 1,
                      'UNSUPPORTED_POLICY' => 1,
                      'PageAttributes.OriginType' => 1,
                      'NotBoundException' => 1,
                      'InternalFrameEvent' => 1,
                      'InstantiationException' => 1,
                      'InputEvent' => 1,
                      'WrongTransaction' => 1,
                      'AccessibleBundle' => 1,
                      'ListModel' => 1,
                      'ToolTipManager' => 1,
                      'TitledBorder' => 1,
                      'SizeLimitExceededException' => 1,
                      'BufferedImageOp' => 1,
                      'NameHelper' => 1,
                      'JobAttributes.DestinationType' => 1,
                      'StyleContext' => 1,
                      'MutableComboBoxModel' => 1,
                      'JToolBar' => 1,
                      'UndoableEditEvent' => 1,
                      'BufferedReader' => 1,
                      'SystemException' => 1,
                      'URLDecoder' => 1,
                      'ObjectFactoryBuilder' => 1,
                      'LogStream' => 1,
                      'Comparable' => 1,
                      'InvalidParameterException' => 1,
                      'ComponentInputMap' => 1,
                      'JComboBox.KeySelectionManager' => 1,
                      'PageAttributes.MediaType' => 1,
                      'AccessibleRole' => 1,
                      'Cloneable' => 1,
                      'MetalLabelUI' => 1,
                      'AccessibleRelation' => 1,
                      'IllegalMonitorStateException' => 1,
                      'SecureClassLoader' => 1,
                      'ARG_INOUT' => 1,
                      'AbstractLayoutCache.NodeDimensions' => 1,
                      'GlyphJustificationInfo' => 1,
                      'ColorSelectionModel' => 1,
                      'BasicStroke' => 1,
                      'Streamable' => 1,
                      'Visibility' => 1,
                      'UShortSeqHolder' => 1,
                      'Statement' => 1,
                      'BasicAttributes' => 1,
                      'DriverPropertyInfo' => 1,
                      'Arc2D.Double' => 1,
                      'ByteHolder' => 1,
                      'TransformAttribute' => 1,
                      'AccessibleTable' => 1,
                      'ComponentOrientation' => 1,
                      'ChangeEvent' => 1,
                      'TreeModelEvent' => 1,
                      'Border' => 1,
                      'AttributeSet.ColorAttribute' => 1,
                      'RMISecurityManager' => 1,
                      'InheritableThreadLocal' => 1,
                      'InvalidSeq' => 1,
                      'OperationNotSupportedException' => 1,
                      'Kernel' => 1,
                      '_NamingContextStub' => 1,
                      'MultiToolBarUI' => 1,
                      'BeanContextServiceAvailableEvent' => 1,
                      'DesignMode' => 1,
                      'Writer' => 1,
                      'ClassLoader' => 1,
                      'Void' => 1,
                      'RemoteServer' => 1,
                      'ObjectOutputStream.PutField' => 1,
                      'IstringHelper' => 1,
                      'DecimalFormat' => 1,
                      'GapContent' => 1,
                      'UnresolvedPermission' => 1,
                      'BAD_INV_ORDER' => 1,
                      'Point2D.Double' => 1,
                      'MalformedURLException' => 1,
                      'Deflater' => 1,
                      'PRIVATE_MEMBER' => 1,
                      'NotEmptyHelper' => 1,
                      'CSS.Attribute' => 1,
                      'Timestamp' => 1,
                      'DefaultTableModel' => 1,
                      'CertificateEncodingException' => 1,
                      'InvalidNameHolder' => 1,
                      'BasicSplitPaneUI' => 1,
                      'DomainManagerOperations' => 1,
                      'PipedReader' => 1,
                      'Member' => 1,
                      'ActivationDesc' => 1,
                      'Initializer' => 1,
                      'AWTEventMulticaster' => 1,
                      'ReflectPermission' => 1,
                      'AffineTransformOp' => 1,
                      'MouseMotionListener' => 1,
                      'AbstractMethodError' => 1,
                      'SecurityPermission' => 1,
                      'VetoableChangeListener' => 1,
                      'PasswordAuthentication' => 1,
                      'AbstractCollection' => 1,
                      'ICC_Profile' => 1,
                      'NO_PERMISSION' => 1,
                      'Panel' => 1,
                      'InitialContextFactoryBuilder' => 1,
                      'BindingIteratorHolder' => 1,
                      'TableColumnModelEvent' => 1,
                      'Context' => 1,
                      'ReverbType' => 1,
                      'PopupMenuListener' => 1,
                      'Option' => 1,
                      'CompoundControl' => 1,
                      'Policy' => 1,
                      'JarOutputStream' => 1,
                      'UnknownUserException' => 1,
                      'MouseInputAdapter' => 1,
                      'LimitExceededException' => 1,
                      'MetalSplitPaneUI' => 1,
                      'JSplitPane' => 1,
                      'LdapContext' => 1,
                      'StateEdit' => 1,
                      'InvalidAttributeIdentifierException' => 1,
                      'StyleConstants.ColorConstants' => 1,
                      'CannotProceedHelper' => 1,
                      'DSAParams' => 1,
                      'RepositoryIdHelper' => 1,
                      'INVALID_TRANSACTION' => 1,
                      'Locale' => 1,
                      'ICC_ProfileGray' => 1,
                      'NegativeArraySizeException' => 1,
                      'ConfigurationException' => 1,
                      'StyledEditorKit.BoldAction' => 1,
                      'AttributeSet.ParagraphAttribute' => 1,
                      'Shape' => 1,
                      'ObjID' => 1,
                      'Line2D.Float' => 1,
                      'BasicSliderUI' => 1,
                      'DefaultComboBoxModel' => 1,
                      'MultiButtonUI' => 1,
                      'TextComponent' => 1,
                      'BAD_POLICY_TYPE' => 1,
                      'AlreadyBoundHolder' => 1,
                      'StyledEditorKit.UnderlineAction' => 1,
                      'MetalTheme' => 1,
                      'NotFoundReasonHelper' => 1,
                      'PropertyChangeListener' => 1,
                      'BasicBorders.SplitPaneBorder' => 1,
                      'MultiInternalFrameUI' => 1,
                      'AWTEventListener' => 1,
                      'MessageDigest' => 1,
                      'JTable' => 1,
                      'MetalComboBoxEditor.UIResource' => 1,
                      'BeanContextChildComponentProxy' => 1,
                      'ListUI' => 1,
                      'ObjectImpl' => 1,
                      'AlreadyBoundHelper' => 1,
                      'Permissions' => 1,
                      'Composite' => 1,
                      'Arc2D.Float' => 1,
                      'ObjectFactory' => 1,
                      'NO_MEMORY' => 1,
                      'UnsupportedClassVersionError' => 1,
                      'InputMethodHighlight' => 1,
                      'AlgorithmParametersSpi' => 1,
                      'MetalComboBoxEditor' => 1,
                      'AlphaComposite' => 1,
                      'RSAPrivateCrtKeySpec' => 1,
                      'BasicOptionPaneUI.ButtonAreaLayout' => 1,
                      'TextUI' => 1,
                      'InvalidName' => 1,
                      'CRL' => 1,
                      'DirectColorModel' => 1,
                      'MenuDragMouseEvent' => 1,
                      'DefaultEditorKit' => 1,
                      'ComponentView' => 1,
                      'Constructor' => 1,
                      'ProgressMonitorInputStream' => 1,
                      'BeanContextSupport' => 1,
                      'PathIterator' => 1,
                      'UIManager.LookAndFeelInfo' => 1,
                      'Transparency' => 1,
                      'TabbedPaneUI' => 1,
                      'NameParser' => 1,
                      'BasicComboBoxEditor.UIResource' => 1,
                      'BindingHelper' => 1,
                      'RectangularShape' => 1,
                      'BorderLayout' => 1,
                      'DesktopIconUI' => 1,
                      'DynFixed' => 1,
                      'UIManager' => 1,
                      'FileSystemView' => 1,
                      'StructMemberHelper' => 1,
                      'CharSeqHelper' => 1,
                      'AbstractMap' => 1,
                      'BasicToolTipUI' => 1,
                      'WriteAbortedException' => 1,
                      'VMID' => 1,
                      'MetalBorders.OptionDialogBorder' => 1,
                      'Dimension2D' => 1,
                      'DragGestureRecognizer' => 1,
                      'FieldView' => 1,
                      'PolicyTypeHelper' => 1,
                      'AccessibleTableModelChange' => 1,
                      'GraphicsConfigTemplate' => 1,
                      'Class' => 1,
                      'DefaultEditorKit.InsertTabAction' => 1,
                      'BasicPopupMenuSeparatorUI' => 1,
                      'NamingSecurityException' => 1,
                      'IntrospectionException' => 1,
                      'StringBufferInputStream' => 1,
                      'JPasswordField' => 1,
                      'Line2D' => 1,
                      'TreeSet' => 1,
                      'PrincipalHolder' => 1,
                      'BasicCheckBoxMenuItemUI' => 1,
                      'MetalBorders.MenuBarBorder' => 1,
                      'SizeRequirements' => 1,
                      'JApplet' => 1,
                      'PropertyChangeSupport' => 1,
                      'ColorConvertOp' => 1,
                      'AllPermission' => 1,
                      'Rectangle2D.Float' => 1,
                      'MetalTextFieldUI' => 1,
                      'Checkbox' => 1,
                      'PermissionCollection' => 1,
                      'MetalBorders.ButtonBorder' => 1,
                      'DefaultFocusManager' => 1,
                      'DSAKeyPairGenerator' => 1,
                      'Socket' => 1,
                      'AudioFormat.Encoding' => 1,
                      'BorderUIResource' => 1,
                      'EventObject' => 1,
                      'SQLInput' => 1,
                      'Observable' => 1,
                      'NVList' => 1,
                      'ObjectChangeListener' => 1,
                      'ActionListener' => 1,
                      'FilteredImageSource' => 1,
                      'SysexMessage' => 1,
                      'Soundbank' => 1,
                      'LdapReferralException' => 1,
                      'DocumentEvent.ElementChange' => 1,
                      'StyledEditorKit.AlignmentAction' => 1,
                      'AppletContext' => 1,
                      '_BindingIteratorImplBase' => 1,
                      'NameAlreadyBoundException' => 1,
                      'BufferedOutputStream' => 1,
                      'BAD_PARAM' => 1,
                      'EventDirContext' => 1,
                      'BasicTreeUI' => 1,
                      'DefaultHighlighter.DefaultHighlightPainter' => 1,
                      'TabStop' => 1,
                      'SoftReference' => 1,
                      'UID' => 1,
                      'Enumeration' => 1,
                      'ZipEntry' => 1,
                      'PERSIST_STORE' => 1,
                      'InterruptedIOException' => 1,
                      'UTFDataFormatException' => 1,
                      'InputMethodRequests' => 1,
                      'Math' => 1,
                      'Stack' => 1,
                      'ResultSetMetaData' => 1,
                      'ExceptionInInitializerError' => 1,
                      'AbstractList' => 1,
                      'Operation' => 1,
                      'JCheckBox' => 1,
                      'Certificate' => 1,
                      'LookupTable' => 1,
                      'DropTarget.DropTargetAutoScroller' => 1,
                      'LongSeqHolder' => 1,
                      'MultiTextUI' => 1,
                      'DocumentEvent' => 1,
                      'MultiTreeUI' => 1,
                      'IllegalArgumentException' => 1,
                      'ServerRef' => 1,
                      'FileView' => 1,
                      'FilterOutputStream' => 1,
                      'NamingExceptionEvent' => 1,
                      'UnknownHostException' => 1,
                      'BasicPanelUI' => 1,
                      'ChangedCharSetException' => 1,
                      'ClassFormatError' => 1,
                      'Instrument' => 1,
                      'ModificationItem' => 1,
                      'CharArrayWriter' => 1,
                      'PropertyVetoException' => 1,
                      'GZIPOutputStream' => 1,
                      'BoxLayout' => 1,
                      'DefaultListCellRenderer' => 1,
                      'X509Extension' => 1,
                      'EncodedKeySpec' => 1,
                      'MultiTabbedPaneUI' => 1,
                      'ARG_OUT' => 1,
                      'NoSuchElementException' => 1,
                      'BasicAttribute' => 1,
                      'Runnable' => 1,
                      'HTMLWriter' => 1,
                      'RootPaneContainer' => 1,
                      'VetoableChangeSupport' => 1,
                      'ObjectStreamException' => 1,
                      'NumberFormatException' => 1,
                      'UnknownException' => 1,
                      'NamingException' => 1,
                      'PaintEvent' => 1,
                      'UndoManager' => 1,
                      'Set' => 1,
                      'BAD_POLICY' => 1,
                      'PrivilegedExceptionAction' => 1,
                      'IntHolder' => 1,
                      'BasicToolBarSeparatorUI' => 1,
                      'SkeletonMismatchException' => 1,
                      'AclNotFoundException' => 1,
                      'RSAKey' => 1,
                      'ArrayIndexOutOfBoundsException' => 1,
                      'PortableRemoteObject' => 1,
                      'OctetSeqHolder' => 1,
                      'CertificateFactorySpi' => 1,
                      'AbstractSequentialList' => 1,
                      'JarInputStream' => 1,
                      'URLEncoder' => 1,
                      'ServiceInformationHelper' => 1,
                      'MetalToggleButtonUI' => 1,
                      'DataInputStream' => 1,
                      'Frame' => 1,
                      'GlyphMetrics' => 1,
                      'HyperlinkEvent.EventType' => 1,
                      'BasicCheckBoxUI' => 1,
                      'ColorModel' => 1,
                      'FloatControl.Type' => 1,
                      'ServerCloneException' => 1,
                      'BindException' => 1,
                      'DigestOutputStream' => 1,
                      'NameComponent' => 1,
                      'DatagramSocketImplFactory' => 1,
                      'Lease' => 1,
                      'BufferedImageFilter' => 1,
                      'ScrollPaneConstants' => 1,
                      'NotSerializableException' => 1,
                      'InvocationEvent' => 1,
                      'IdentifierHelper' => 1,
                      'UIDefaults' => 1,
                      'StringBuffer' => 1,
                      'MetalTreeUI' => 1,
                      'FocusAdapter' => 1,
                      'Bounds' => 1,
                      'DSAPublicKeySpec' => 1,
                      'InternalFrameListener' => 1,
                      'ActivationGroupDesc' => 1,
                      'PrivilegedActionException' => 1,
                      'JCheckBoxMenuItem' => 1,
                      'JWindow' => 1,
                      'Long' => 1,
                      'UnknownGroupException' => 1,
                      'BinaryRefAddr' => 1,
                      'Paint' => 1,
                      'FixedHeightLayoutCache' => 1,
                      'RasterOp' => 1,
                      'SizeSequence' => 1,
                      'X509EncodedKeySpec' => 1,
                      'ButtonUI' => 1,
                      'DefaultTreeModel' => 1,
                      'InvalidKeySpecException' => 1,
                      'MalformedLinkException' => 1,
                      'ShortHolder' => 1,
                      'MetalIconFactory.TreeLeafIcon' => 1,
                      'InvalidTransactionException' => 1,
                      'InitialLdapContext' => 1,
                      'ValueMemberHelper' => 1,
                      'RenderContext' => 1,
                      'HyperlinkEvent' => 1,
                      'ActivateFailedException' => 1,
                      'PreparedStatement' => 1,
                      'MidiMessage' => 1,
                      'LocateRegistry' => 1,
                      'BasicScrollBarUI' => 1,
                      'BasicComboBoxUI' => 1,
                      'JTree.EmptySelectionModel' => 1,
                      'BasicBorders' => 1,
                      'FREE_MEM' => 1,
                      'Process' => 1,
                      'EventListener' => 1,
                      'JColorChooser' => 1,
                      'KeyStoreSpi' => 1,
                      'CertificateNotYetValidException' => 1,
                      'FileChooserUI' => 1,
                      'KeyException' => 1,
                      'MissingResourceException' => 1,
                      'Integer' => 1,
                      'SyncFailedException' => 1,
                      'DSAPublicKey' => 1,
                      'ToolBarUI' => 1,
                      'BadKind' => 1,
                      'BorderUIResource.EmptyBorderUIResource' => 1,
                      'AttributeSet.CharacterAttribute' => 1,
                      'DefaultTableCellRenderer.UIResource' => 1,
                      'Struct' => 1,
                      'ArithmeticException' => 1,
                      'AccessibleValue' => 1,
                      'ComponentAdapter' => 1,
                      'ServiceDetailHelper' => 1,
                      'RemoteStub' => 1,
                      'FlowView' => 1,
                      'Thread' => 1,
                      'AttributeList' => 1,
                      'Float' => 1,
                      'FileFilter' => 1,
                      'MultiTableHeaderUI' => 1,
                      'LineNumberInputStream' => 1,
                      'UnsupportedEncodingException' => 1,
                      'NamespaceChangeListener' => 1,
                      'StreamableValue' => 1,
                      'MetalBorders.InternalFrameBorder' => 1,
                      'GlyphVector' => 1,
                      'StyleConstants.FontConstants' => 1,
                      'CSS' => 1,
                      'RuntimePermission' => 1,
                      'ButtonGroup' => 1,
                      'UnknownServiceException' => 1,
                      'JDialog' => 1,
                      'NoninvertibleTransformException' => 1,
                      'SoundbankReader' => 1,
                      'Dimension' => 1,
                      'Key' => 1,
                      'AttributeSet' => 1,
                      'AbstractDocument.AttributeContext' => 1,
                      'Permission' => 1,
                      'BasicDirectoryModel' => 1,
                      'BasicSeparatorUI' => 1,
                      'BAD_TYPECODE' => 1,
                      'URLStreamHandlerFactory' => 1,
                      'AncestorEvent' => 1,
                      'ByteArrayOutputStream' => 1,
                      'PrintGraphics' => 1,
                      'ExtendedRequest' => 1,
                      'HTML.Tag' => 1,
                      'Character' => 1,
                      'NoSuchMethodError' => 1,
                      'DefaultBoundedRangeModel' => 1,
                      'SystemColor' => 1,
                      'InconsistentTypeCode' => 1,
                      'DataFormatException' => 1,
                      'DefaultHighlighter' => 1,
                      'MenuKeyEvent' => 1,
                      'Collator' => 1,
                      'RunTime' => 1,
                      'OptionPaneUI' => 1,
                      'AccessibleText' => 1,
                      'CheckedOutputStream' => 1,
                      'DefaultStyledDocument' => 1,
                      '_PolicyStub' => 1,
                      'ULongSeqHelper' => 1,
                      'MultiSplitPaneUI' => 1,
                      'ShortLookupTable' => 1,
                      'BooleanSeqHolder' => 1,
                      'FileInputStream' => 1,
                      'Renderer' => 1,
                      'DropTargetEvent' => 1,
                      'BeanContextChild' => 1,
                      'AccessibleComponent' => 1,
                      'BasicIconFactory' => 1,
                      'AudioSystem' => 1,
                      'TableColumn' => 1,
                      'BufferedInputStream' => 1,
                      'BasicLabelUI' => 1,
                      'UserException' => 1,
                      'Sequence' => 1,
                      'NO_RESOURCES' => 1,
                      'NoSuchFieldError' => 1,
                      'TreeExpansionListener' => 1,
                      'SQLOutput' => 1,
                      'IncompatibleClassChangeError' => 1,
                      'Insets' => 1,
                      'ScrollPaneLayout.UIResource' => 1,
                      'Referenceable' => 1,
                      'InputMapUIResource' => 1,
                      'SocketImplFactory' => 1,
                      'InputMethodEvent' => 1,
                      'ResponseHandler' => 1,
                      'KeyAdapter' => 1,
                      'JInternalFrame' => 1,
                      'BeanContextContainerProxy' => 1,
                      'KeyEvent' => 1,
                      'BeanDescriptor' => 1,
                      'Button' => 1,
                      'PipedOutputStream' => 1,
                      'AccessibleContext' => 1,
                      'Driver' => 1,
                      'CellEditor' => 1,
                      'KeyStore' => 1,
                      'StrictMath' => 1,
                      'DoubleHolder' => 1,
                      'FileNameMap' => 1,
                      'TextHitInfo' => 1,
                      'PushbackReader' => 1,
                      'TextListener' => 1,
                      'RoundRectangle2D.Double' => 1,
                      'ObjectStreamClass' => 1,
                      'NetPermission' => 1,
                      'ServerRuntimeException' => 1,
                      'Proxy' => 1,
                      'MetalScrollBarUI' => 1,
                      'AccessController' => 1,
                      'NoInitialContextException' => 1,
                      'DefaultStyledDocument.AttributeUndoableEdit' => 1,
                      'IndexColorModel' => 1,
                      'InputMethodDescriptor' => 1,
                      'QuadCurve2D.Float' => 1,
                      'ParserDelegator' => 1,
                      'MetalToolBarUI' => 1,
                      'TransactionRolledbackException' => 1,
                      'LabelView' => 1,
                      'TreeUI' => 1,
                      'TexturePaint' => 1,
                      'DefaultEditorKit.InsertBreakAction' => 1,
                      'Event' => 1,
                      'URLConnection' => 1,
                      'PrintJob' => 1,
                      'CompositeView' => 1,
                      'PolicyHolder' => 1,
                      'RenderableImageOp' => 1,
                      'PackedColorModel' => 1,
                      'Arc2D' => 1,
                      'HTMLEditorKit.LinkController' => 1,
                      'StyledDocument' => 1,
                      'BasicScrollPaneUI' => 1,
                      'Introspector' => 1,
                      'TreeCellRenderer' => 1,
                      'GlyphView' => 1,
                      'MultipleMaster' => 1,
                      'TransactionRequiredException' => 1,
                      'Line2D.Double' => 1,
                      'Array' => 1,
                      'ImageIcon' => 1,
                      'KeyListener' => 1,
                      'BoxView' => 1,
                      'PopupMenuEvent' => 1,
                      'Timer' => 1,
                      'INV_IDENT' => 1,
                      'NotFoundHolder' => 1,
                      'BeanContextServices' => 1,
                      'BasicTextPaneUI' => 1,
                      'JTabbedPane' => 1,
                      'AudioFileWriter' => 1,
                      'JTableHeader' => 1,
                      '_IDLTypeStub' => 1,
                      'ORB' => 1,
                      'BasicToolBarUI' => 1,
                      'DataBufferUShort' => 1,
                      'MouseAdapter' => 1,
                      'TableColumnModelListener' => 1,
                      'DefaultListModel' => 1,
                      'DataBufferByte' => 1,
                      'UndoableEditListener' => 1,
                      'CommunicationException' => 1,
                      'StyleSheet' => 1,
                      'ZoneView' => 1,
                      'Style' => 1,
                      'InsetsUIResource' => 1,
                      'CardLayout' => 1,
                      'INV_FLAG' => 1,
                      'SignatureSpi' => 1,
                      'DropTargetDropEvent' => 1,
                      'ItemListener' => 1,
                      'ResultSet' => 1,
                      'Pageable' => 1,
                      'Manifest' => 1,
                      'ExtendedResponse' => 1,
                      'ComboPopup' => 1,
                      'ImageConsumer' => 1,
                      'HTMLEditorKit.HTMLTextAction' => 1,
                      'MinimalHTMLWriter' => 1,
                      'InflaterInputStream' => 1,
                      'TimerTask' => 1,
                      'HyperlinkListener' => 1,
                      'SQLWarning' => 1,
                      'AclEntry' => 1,
                      'DynValue' => 1,
                      'KeyFactory' => 1,
                      'LayoutQueue' => 1,
                      'ProviderException' => 1,
                      'BasicColorChooserUI' => 1,
                      'X509Certificate' => 1,
                      'ListSelectionModel' => 1,
                      'MenuEvent' => 1,
                      'MouseDragGestureRecognizer' => 1,
                      'BasicTextUI' => 1,
                      'MessageDigestSpi' => 1,
                      'Calendar' => 1,
                      'ScrollBarUI' => 1,
                      'Double' => 1,
                      'CubicCurve2D' => 1,
                      'CubicCurve2D.Double' => 1,
                      'DigestInputStream' => 1,
                      'InputStreamReader' => 1,
                      'RenderedImage' => 1,
                      'AreaAveragingScaleFilter' => 1,
                      'DomainManager' => 1,
                      'SearchControls' => 1,
                      'CompletionStatus' => 1,
                      'ParagraphView' => 1,
                      'ConnectException' => 1,
                      'BindingType' => 1,
                      'StyledEditorKit.FontFamilyAction' => 1,
                      'UnicastRemoteObject' => 1,
                      'PushbackInputStream' => 1,
                      'JPopupMenu' => 1,
                      'RSAPublicKey' => 1,
                      'Parser' => 1,
                      'InvocationTargetException' => 1,
                      'ViewFactory' => 1,
                      'ActivationMonitor' => 1,
                      'INV_POLICY' => 1,
                      'ClipboardOwner' => 1,
                      'UnionMemberHelper' => 1,
                      'BigInteger' => 1,
                      'Highlighter' => 1,
                      'UIDefaults.ActiveValue' => 1,
                      'BindingHolder' => 1,
                      'MetalComboBoxUI' => 1,
                      'Guard' => 1,
                      'GlyphView.GlyphPainter' => 1,
                      'DynEnum' => 1,
                      'RenderableImage' => 1,
                      'BasicComboBoxEditor' => 1,
                      'BeanContextServicesSupport' => 1,
                      'DefaultMutableTreeNode' => 1,
                      'SeparatorUI' => 1,
                      'SwingConstants' => 1,
                      'BasicButtonListener' => 1,
                      'LinkLoopException' => 1,
                      'TabExpander' => 1,
                      'IdentityScope' => 1,
                      'OMGVMCID' => 1,
                      'TreeModel' => 1,
                      'ListDataListener' => 1,
                      'MetalScrollPaneUI' => 1,
                      'JFrame' => 1,
                      'AbstractSet' => 1,
                      'InvalidSearchFilterException' => 1,
                      'BasicTextAreaUI' => 1,
                      'ExportException' => 1,
                      'JScrollPane' => 1,
                      'SwingPropertyChangeSupport' => 1,
                      'CharacterIterator' => 1,
                      'InvalidDnDOperationException' => 1,
                      'UnsupportedLookAndFeelException' => 1,
                      'LayeredHighlighter.LayerPainter' => 1,
                      'JProgressBar' => 1,
                      'DefaultListCellRenderer.UIResource' => 1,
                      'Activator' => 1,
                      'ActivationGroupDesc.CommandEnvironment' => 1,
                      'FilterWriter' => 1,
                      'ValueMember' => 1,
                      'AuthenticationException' => 1,
                      'AccessibleObject' => 1,
                      'ResolveResult' => 1,
                      'IconUIResource' => 1,
                      'ItemSelectable' => 1,
                      'SerializablePermission' => 1,
                      'PrivilegedAction' => 1,
                      'Checksum' => 1,
                      'BasicTableHeaderUI' => 1,
                      'IllegalAccessError' => 1,
                      'InvalidNameHelper' => 1,
                      'ProgressBarUI' => 1,
                      'Runtime' => 1,
                      'InitialContextFactory' => 1,
                      'AbstractTableModel' => 1,
                      'GeneralPath' => 1,
                      'AbstractDocument' => 1,
                      'ComponentEvent' => 1,
                      'LoaderHandler' => 1,
                      'Acl' => 1,
                      'JComponent' => 1,
                      'MouseInputListener' => 1,
                      'WritableRenderedImage' => 1,
                      'FloatSeqHelper' => 1,
                      'OBJ_ADAPTER' => 1,
                      'NamingContextOperations' => 1,
                      'BorderUIResource.EtchedBorderUIResource' => 1,
                      'FieldNameHelper' => 1,
                      'DropTargetDragEvent' => 1,
                      'FileOutputStream' => 1,
                      'Synthesizer' => 1,
                      'SocketOptions' => 1,
                      'ProgressMonitor' => 1,
                      'DropTarget' => 1,
                      'JViewport' => 1,
                      'AsyncBoxView' => 1,
                      'StubDelegate' => 1,
                      'SimpleBeanInfo' => 1,
                      'RandomAccessFile' => 1,
                      'BorderFactory' => 1,
                      'Track' => 1,
                      'HTMLEditorKit.Parser' => 1,
                      'MetalSliderUI' => 1,
                      'BasicRadioButtonMenuItemUI' => 1,
                      'RescaleOp' => 1,
                      'ComponentSampleModel' => 1,
                      'CompletionStatusHelper' => 1,
                      'StringHolder' => 1,
                      'JInternalFrame.JDesktopIcon' => 1,
                      'MultiScrollPaneUI' => 1,
                      'InputMethodListener' => 1,
                      'ObjectStreamField' => 1,
                      'Adjustable' => 1,
                      'BAD_POLICY_VALUE' => 1,
                      'Stub' => 1,
                      'Book' => 1,
                      'ServerError' => 1,
                      'FlatteningPathIterator' => 1,
                      'Color' => 1,
                      'CloneNotSupportedException' => 1,
                      'DataFlavor' => 1,
                      'BreakIterator' => 1,
                      'EmptyStackException' => 1,
                      'ListView' => 1,
                      'PropertyDescriptor' => 1,
                      'PixelInterleavedSampleModel' => 1,
                      'FlowView.FlowStrategy' => 1,
                      'ControlFactory' => 1,
                      'VM_CUSTOM' => 1,
                      'TableModelListener' => 1,
                      'PropertyResourceBundle' => 1,
                      'ProtocolException' => 1,
                      'FloatHolder' => 1,
                      'ImageProducer' => 1,
                      'HTMLEditorKit.ParserCallback' => 1,
                      'CustomMarshal' => 1,
                      'MenuShortcut' => 1,
                      'AttributeInUseException' => 1,
                      'PageAttributes.ColorType' => 1,
                      'FontMetrics' => 1,
                      'DateFormat' => 1,
                      'TextArea' => 1,
                      'PrinterException' => 1,
                      'AbstractWriter' => 1,
                      'TimeLimitExceededException' => 1,
                      'DesktopPaneUI' => 1,
                      'BorderUIResource.CompoundBorderUIResource' => 1,
                      'UndoableEdit' => 1,
                      'CannotProceedHolder' => 1,
                      'CallableStatement' => 1,
                      'Icon' => 1,
                      'WindowConstants' => 1,
                      'UnsupportedAudioFileException' => 1,
                      'MidiFileFormat' => 1,
                      'UIDefaults.ProxyLazyValue' => 1,
                      'Date' => 1,
                      'MultiColorChooserUI' => 1,
                      'CompoundEdit' => 1,
                      'BeanInfo' => 1,
                      'ServiceInformation' => 1,
                      'Caret' => 1,
                      'AudioClip' => 1,
                      'AccessControlException' => 1,
                      'LineListener' => 1,
                      'MenuBar' => 1,
                      'NamingEvent' => 1,
                      'ListDataEvent' => 1,
                      'ContainerEvent' => 1,
                      'NO_IMPLEMENT' => 1,
                      'Connection' => 1,
                      'DateFormatSymbols' => 1,
                      'QuadCurve2D' => 1,
                      'DefaultMetalTheme' => 1,
                      'AttributedString' => 1,
                      'MidiDevice' => 1,
                      'FeatureDescriptor' => 1,
                      'JRadioButton' => 1,
                      'DataLine.Info' => 1,
                      'DATA_CONVERSION' => 1,
                      'Image' => 1,
                      'JMenu' => 1,
                      'Reader' => 1,
                      'PlainDocument' => 1,
                      'DriverManager' => 1,
                      'Area' => 1,
                      'EditorKit' => 1,
                      'AppletInitializer' => 1,
                      'Attribute' => 1,
                      'TagElement' => 1,
                      'MetalBorders.PaletteBorder' => 1,
                      'AnySeqHolder' => 1,
                      'RepaintManager' => 1,
                      'PlainView' => 1,
                      'MultiToolTipUI' => 1,
                      'MultiDesktopPaneUI' => 1,
                      'FlavorMap' => 1,
                      'RuleBasedCollator' => 1,
                      'CRC32' => 1,
                      'LineMetrics' => 1,
                      'SignatureException' => 1,
                      'DocumentParser' => 1,
                      'InlineView' => 1,
                      'ConvolveOp' => 1,
                      'CertificateParsingException' => 1,
                      'AWTPermission' => 1,
                      'UnrecoverableKeyException' => 1,
                      'Signer' => 1,
                      'RoundRectangle2D' => 1,
                      'MimeTypeParseException' => 1,
                      'BasicHTML' => 1,
                      'EventSetDescriptor' => 1,
                      'KeyManagementException' => 1,
                      'ComboBoxModel' => 1,
                      'HTMLEditorKit.HTMLFactory' => 1,
                      'JarEntry' => 1,
                      'NameNotFoundException' => 1,
                      'DragSource' => 1,
                      'MultiTableUI' => 1,
                      'ARG_IN' => 1,
                      'InputVerifier' => 1,
                      'FocusEvent' => 1,
                      'MemoryImageSource' => 1,
                      'BasicDesktopPaneUI' => 1,
                      'HierarchyBoundsListener' => 1,
                      'Attributes' => 1,
                      'Control' => 1,
                      'ActionEvent' => 1,
                      'BasicOptionPaneUI' => 1,
                      'NotActiveException' => 1,
                      'WCharSeqHolder' => 1,
                      'TimeZone' => 1,
                      'BasicBorders.ToggleButtonBorder' => 1,
                      'DragSourceListener' => 1,
                      'JTextField' => 1,
                      'TreeWillExpandListener' => 1,
                      'Entity' => 1,
                      'BevelBorder' => 1,
                      'StateFactory' => 1,
                      'WindowEvent' => 1,
                      'StyleConstants.ParagraphConstants' => 1,
                      'GraphicsConfiguration' => 1,
                      'JSeparator' => 1,
                      'QuadCurve2D.Double' => 1,
                      'StyledEditorKit' => 1,
                      'MetalBorders.ScrollPaneBorder' => 1,
                      'BasicTableUI' => 1,
                      'PipedInputStream' => 1,
                      'Graphics2D' => 1,
                      'DimensionUIResource' => 1,
                      'SignedObject' => 1,
                      'ExceptionList' => 1,
                      'DataOutput' => 1,
                      'Receiver' => 1,
                      'BasicTabbedPaneUI' => 1,
                      'DefaultEditorKit.PasteAction' => 1,
                      'AttributeSet.FontAttribute' => 1,
                      'DefaultEditorKit.DefaultKeyTypedAction' => 1,
                      'InvalidAlgorithmParameterException' => 1,
                      'NoSuchMethodException' => 1,
                      'InvalidNameException' => 1,
                      'RemoteCall' => 1,
                      'Vector' => 1,
                      'RSAKeyGenParameterSpec' => 1,
                      'MediaTracker' => 1,
                      'TypeMismatch' => 1,
                      'LineBorder' => 1,
                      'Action' => 1,
                      'ComboBoxUI' => 1,
                      'MultiFileChooserUI' => 1,
                      'Autoscroll' => 1,
                      'DefinitionKindHelper' => 1,
                      'FocusManager' => 1,
                      'DefaultEditorKit.InsertContentAction' => 1,
                      'Group' => 1,
                      'Owner' => 1,
                      'StringContent' => 1,
                      'SampleModel' => 1,
                      'TreeSelectionEvent' => 1,
                      'BasicPasswordFieldUI' => 1,
                      'FilterInputStream' => 1,
                      'Point2D.Float' => 1,
                      'NoSuchObjectException' => 1,
                      'Boolean' => 1,
                      'ArrayStoreException' => 1,
                      'DefaultTextUI' => 1,
                      'RMIFailureHandler' => 1,
                      'CellRendererPane' => 1,
                      'VirtualMachineError' => 1,
                      'ValueFactory' => 1,
                      'MultiScrollBarUI' => 1,
                      'StyledEditorKit.FontSizeAction' => 1,
                      'DatabaseMetaData' => 1,
                      'BorderUIResource.LineBorderUIResource' => 1,
                      'BasicArrowButton' => 1,
                      'RootPaneUI' => 1,
                      'BindingIteratorOperations' => 1,
                      'BorderUIResource.BevelBorderUIResource' => 1,
                      'BAD_CONTEXT' => 1,
                      'DGC' => 1,
                      'TRANSIENT' => 1,
                      'ToolTipUI' => 1,
                      'AppletStub' => 1,
                      'TabSet' => 1,
                      'BooleanControl' => 1,
                      'InputMethod' => 1,
                      'JarException' => 1,
                      'ThreadDeath' => 1,
                      'Properties' => 1,
                      'GZIPInputStream' => 1,
                      'WeakHashMap' => 1,
                      'BeanContextServicesListener' => 1,
                      'TableModel' => 1,
                      'BandCombineOp' => 1,
                      'SimpleTimeZone' => 1,
                      'MenuListener' => 1,
                      'PropertyEditor' => 1,
                      'PrinterIOException' => 1,
                      'LongSeqHelper' => 1,
                      'MultiListUI' => 1,
                      'CertificateFactory' => 1,
                      'List' => 1,
                      'CannotRedoException' => 1,
                      'StyleConstants' => 1,
                      'RTFEditorKit' => 1,
                      'SourceDataLine' => 1,
                      'EtchedBorder' => 1,
                      'SplitPaneUI' => 1,
                      'InputMethodContext' => 1,
                      'CharArrayReader' => 1,
                      'LineEvent.Type' => 1,
                      'LinkedList' => 1,
                      'StringRefAddr' => 1,
                      'PolicyListHelper' => 1,
                      'NoPermissionException' => 1,
                      'BasicBorders.RadioButtonBorder' => 1,
                      'TreeNode' => 1,
                      'Arrays' => 1,
                      'MenuSelectionManager' => 1,
                      'CertificateException' => 1,
                      'CompoundName' => 1,
                      'Choice' => 1,
                      'UnsupportedOperationException' => 1,
                      'LineNumberReader' => 1,
                      'WStringValueHelper' => 1,
                      'DefaultTreeCellRenderer' => 1,
                      'BoxedValueHelper' => 1,
                      'SetOverrideType' => 1,
                      'DefaultEditorKit.CopyAction' => 1,
                      'CharConversionException' => 1,
                      'InstantiationError' => 1,
                      'UtilDelegate' => 1,
                      'MultiOptionPaneUI' => 1,
                      'BoundedRangeModel' => 1,
                      'DnDConstants' => 1,
                      'TextEvent' => 1,
                      'ServiceUnavailableException' => 1,
                      'LayoutManager2' => 1,
                      'JobAttributes.DialogType' => 1,
                      'Binding' => 1,
                      'CRLException' => 1,
                      'ActionMapUIResource' => 1,
                      'EventQueue' => 1,
                      'LayoutManager' => 1,
                      'AdjustmentListener' => 1,
                      'HTML.Attribute' => 1,
                      'MetaMessage' => 1,
                      'SwingUtilities' => 1,
                      'TreeExpansionEvent' => 1,
                      'Line' => 1,
                      'HttpURLConnection' => 1,
                      'WritableRaster' => 1,
                      'NotFoundHelper' => 1,
                      'MidiSystem' => 1,
                      'BasicViewportUI' => 1,
                      'MidiFileReader' => 1,
                      'Canvas' => 1,
                      'DropTargetListener' => 1,
                      'SystemFlavorMap' => 1,
                      'BasicInternalFrameTitlePane' => 1,
                      'SortedSet' => 1,
                      'CannotProceedException' => 1,
                      'CurrentHolder' => 1,
                      'Map' => 1,
                      'Container' => 1,
                      'ParameterBlock' => 1,
                      'CMMException' => 1,
                      'UndeclaredThrowableException' => 1,
                      'TooManyListenersException' => 1,
                      'Raster' => 1,
                      'MetalInternalFrameTitlePane' => 1,
                      'AccessibleSelection' => 1,
                      'AccessibleHyperlink' => 1,
                      'Utilities' => 1,
                      'Scrollable' => 1,
                      'InitialContext' => 1,
                      'ServiceInformationHolder' => 1,
                      'Point2D' => 1,
                      'BitSet' => 1,
                      'Blob' => 1,
                      'UnsupportedFlavorException' => 1,
                      'StyleConstants.CharacterConstants' => 1,
                      'Annotation' => 1,
                      'ObjectHolder' => 1,
                      'BasicMenuUI' => 1,
                      'ResourceBundle' => 1,
                      'Activatable' => 1,
                      'HTML.UnknownTag' => 1,
                      'NamedValue' => 1,
                      'DomainCombiner' => 1,
                      'MultiPopupMenuUI' => 1,
                      'HashSet' => 1,
                      'Observer' => 1,
                      'AWTException' => 1,
                      'AuthenticationNotSupportedException' => 1,
                      'ArrayList' => 1,
                      'StringReader' => 1,
                      'BooleanSeqHelper' => 1,
                      'MetalBorders.ToolBarBorder' => 1,
                      'BasicFileChooserUI' => 1,
                      'ObjectInputStream' => 1,
                      'MultiSliderUI' => 1,
                      'DSAPrivateKey' => 1,
                      'AudioFileFormat.Type' => 1,
                      'AbstractColorChooserPanel' => 1,
                      'VerifyError' => 1,
                      'Time' => 1,
                      'NoRouteToHostException' => 1,
                      'MarshalledObject' => 1,
                      'DirObjectFactory' => 1,
                      'ZipException' => 1,
                      'UnsolicitedNotificationEvent' => 1,
                      'JTextArea' => 1,
                      'Label' => 1,
                      'MetalPopupMenuSeparatorUI' => 1,
                      'MultiDesktopIconUI' => 1,
                      'AudioFileFormat' => 1,
                      'Delegate' => 1,
                      'DesktopManager' => 1,
                      'LookAndFeel' => 1,
                      'MidiDevice.Info' => 1,
                      'InterruptedException' => 1,
                      'MARSHAL' => 1,
                      'Remote' => 1,
                      'ProtectionDomain' => 1,
                      'TableModelEvent' => 1,
                      'ULongLongSeqHelper' => 1,
                      'StyleSheet.ListPainter' => 1,
                      'Rectangle2D.Double' => 1,
                      'Customizer' => 1,
                      'BasicToggleButtonUI' => 1,
                      'StyledEditorKit.StyledTextAction' => 1,
                      'TreeCellEditor' => 1,
                      'MutableTreeNode' => 1,
                      'DirContext' => 1,
                      'Line.Info' => 1
                    },
          'lineComment' => [
                             '//'
                           ],
          'delimiters' => ',(){}[]-+*%/="\'~!&|<>?:;.',
          'key1' => {
                      'false' => 1,
                      'static' => 1,
                      'native' => 1,
                      'if' => 1,
                      'double' => 1,
                      'interface' => 1,
                      'new' => 1,
                      'extends' => 1,
                      'this' => 1,
                      'break' => 1,
                      'for' => 1,
                      'private' => 1,
                      'default' => 1,
                      'else' => 1,
                      'null' => 1,
                      'byte' => 1,
                      'final' => 1,
                      'continue' => 1,
                      'class' => 1,
                      'abstract' => 1,
                      'instanceof' => 1,
                      'synchronized' => 1,
                      'int' => 1,
                      'do' => 1,
                      'void' => 1,
                      'true' => 1,
                      'transient' => 1,
                      'case' => 1,
                      'short' => 1,
                      'boolean' => 1,
                      'float' => 1,
                      'public' => 1,
                      'long' => 1,
                      'implements' => 1,
                      'volatile' => 1,
                      'threadsafe' => 1,
                      'throw' => 1,
                      'super' => 1,
                      'protected' => 1,
                      'return' => 1,
                      'import' => 1,
                      'package' => 1,
                      'finally' => 1,
                      'while' => 1,
                      'length' => 1,
                      'try' => 1,
                      'switch' => 1,
                      'char' => 1,
                      'catch' => 1,
                      'throws' => 1
                    },
          'quot' => [
                      '\'',
                      '"'
                    ],
          'blockCommentOff' => [
                                 '*/'
                               ],
          'escape' => '\\',
          'continueQuote' => 0
        };

}

1;
__END__
